*CMZU:  1.99/11 06/07/95  23.20.18  by  Curtis A. Meyer
*CMZ :  1.95/00 06/03/95  18.06.28  by  Christian Voelcker
*CMZU:  1.94/04 10/02/95  17.17.15  by  Curtis A. Meyer
*CMZU:  1.93/05 27/11/94  14.02.33  by  D.S.Armstrong
*CMZ :          27/11/94  14.01.37  by  D.S.Armstrong
* add cuts to get rid of many outliers
*CMZ :          25/11/94  17.05.24  by  D.S.Armstrong
*CMZU:  1.60/05 31/01/94  11.09.21  by  R.BOSSINGHAM
*CMZU:  1.51/04 17/04/92  09.08.14  by  Curtis A. Meyer
*CMZ :  1.51/03 09/04/92  18.09.51  by  Curtis A. Meyer
*CMZ :  1.50/18 13/12/91  10.34.03  by  Curtis A. Meyer
*CMZU:  1.50/17 30/11/91  11.42.50  by  Michael Doser
*CMZ :          30/11/91  11.41.57  by  Michael Doser
*                 fix to guard against integer overflow
*                 when calculating time by weighted mean
*CMZU:          06/11/91  10.25.32  by  Curtis A. Meyer
*CMZ :  1.49/01 15/08/91  08.23.16  by  Curtis A. Meyer
*CMZ :  1.46/04 30/04/91  15.07.49  by  Curtis A. Meyer
*CMZ :  1.45/00 15/01/91  13.33.21  by  Curtis A. Meyer
*CMZU:  1.44/10 16/12/90  21.17.15  by  CURTIS A. MEYER
*CMZ :  1.44/09 11/11/90  14.04.05  by  Curtis A. Meyer
*CMZ :  1.44/06 27/10/90  13.14.12  by  Curtis A. Meyer
*CMZ :  1.43/05 21/09/90  07.48.26  by  Curtis A. Meyer
*CMZ :  1.42/00 11/07/90  08.27.26  by  Curtis A. Meyer
*-- Author :  Curtis A. Meyer  8 May 1989
      SUBROUTINE RJPROC(IERR)
*
*        Author:        Curtis A Meyer
*
*        Creation date:  8 May,     1989
*        Modified:         January, 1990
*        Modified:      27 April,   1990
*        Modified:      26 October, 1990
*        Modified:      15 August,  1991
*        Modified:      25 November,1991
*        Modified:      13 December,1991
*        Modified:      09 April,   1992
*        Modified:      31 January, 1994
*        Modified:      10 February, 1995
*
*        References:
*
*        Description:   This routine will take the unprocessed RJDF
*                       data, process, and store it in the RJDC data
*                       bank.  RJDF ==> RJDC banks:
*
*            RJDF bank: (bits 17-32)       bits(1-16)
*              +1       Code, FFFB         Number of I*4 words
*              +2     Number of I*2chan    Sector-Layer-code
*              +3       CRATE NUMBER       Time offset
*              +4       Pedestal_right     Pedestal_left
*              +5       Chan. 1 L+R        Chan. 2 L+R
*              +6           .                  .
*              +7           .                  .
*
*            RJDC bank: (bits 17-32)       bits(1-16)
*              +1       Number I*2 words   Header and format ..
*              +2       Block lenght I*4   Time conversion
*              +3       T0 subtracted      Dynamic Pedestal
*              +4           0                  0
*              +5       Marker FFFD        Number of I*2 to follow
*              +6       layer/sector       Drift time
*              +7       Charge left        Charge right
*              +8  repeat the last two for every hit:
*
*        Edit History: 1 June, 1989 C.A. Meyer
*                      Treated the tape pedestal correctly. The value
*                      in the RJDF bank is ten times the linearized
*                      value.
*
*                      30 October, 1989 C.A. Meyer
*
*                         January, 1990 C.A. Meyer
*                      Allow for machine dependent bit manipulation.
*
*                      27 April, 1990 C.A.Meyer
*                      Allow for t0 not to be subtracted, and include
*                      the possibility of dynamic pedestal subtraction.
*
*                      26 October, 1990 --- C.A.Meyer
*                      Added checking to make sure that the data will
*                      not overflow the IPUL array. If it would, the
*                      routine will return with IERR=-1, and thereby
*                      flag the event to be aborted.
*
*                      15 August, 1991  --- C.A.Meyer
*                      Modify computation of time to do amplitude
*                      weighting rather than simple averages.
*                      Also require that the amplitude sum be larger
*                      than zero to keep a pulse.
*
*                      13 December, 1991 --- C.A.Meyer
*                      Flag pulses with the maximum number of channels
*                      as "buggy", and discard them. They will be
*                      counted in ISTKTC(21), and logged.
*
*                      09 April, 1992  --- C.A.Meyer
*                      Fixed a bug in the code that was looking for
*                      holes in the raw pulses. This bug could do
*                      really wierd things to the pulses.
*
*                      31 January, 1994 --- R.Bossingham
*                      Correct for JDC amplifier non-linearity here,
*                      where it can also be used for leading edge study.
*
*                      10 Feb. 1995  C.A.Meyer
*                      Fixed LIN40 problem in checking for missing
*                      data in a signal.
*
*     ****************************************************************
*
*KEEP,IMPNONE,IF=-F77.
      IMPLICIT NONE
*KEND.
*
*        Passed variables:
*        IERR  Returned as zero for successful operation.
*
      INTEGER  IERR
*
*        Internal variables:
*        IRJDF  Internal pointer to the RJDF data bank.
*        KRJDF  Bank pointer, either RJDF or RGDG.
*        IRJDC  Internal pointer to the RJDC data bank.
*
      INTEGER      IRJDF,KRJDF,IRJDC
*
*        I      Loop index.
*        NLFT   Number of pulses on left.
*        NRGT   Number of pulses on right.
*        IBEGL  Start integration on left.
*        IENDL  Finish integration on left.
*        IBEGR  Start integration on left.
*        IENDL  Finish integration on right.
*
      INTEGER   I,NLFT,NRGT,IBEGL,IENDL,IBEGR,IENDR
*
*        IPULR   The raw pulse on the right side.
*        IPULL   The raw pulse on the left  side.
*
      INTEGER   IPULR(0:1024),IPULL(0:1024)
*
*        IWORD  Word count.
*        NWORD  Number of I*4 words in the RJDF data bank.
*        LYSEC  The Layer/sector coded for this hit.
*        ICRAT  FADC Crate number.
*        ILYR   Layer number.
*        ISEC   Sector number.
*
      INTEGER   IWORD,NWORD,LYSEC,II,JJ,ICRAT,ILYR,ISEC
*
*        IALFT  Amplitude on the left side.
*        IARGT  Amplitude on the right side.
*        IAOFL  Correction on left side for double pulses.
*        IAOFR  Correction on right side for double pulses.
*        ITDIF  Difference in times between left and right.
*        NDATA
*        ICODE
*        ICRAT  FADC Crate number
*        IASUM
*
      INTEGER   IALFT,IARGT,IAOFL,IAOFR,ITDIF,NDATA,ICODE,IASUM
*
*        ITIME  Fit drift time of pulse.
*        ITIML  Left Time.
*        ITIMR  Right Time.
*        IL,IR  Loop indicies over left and right pulses.
*        INTGL  Integration time on left side.
*        INTGR  Integration time on right side.
*        ILP2   Used in computing the pedestals dynamically.
*        IRP2   Used in computing the pedestals dynamically.
*
      INTEGER   ITIME,ITIML,ITIMR,IL,IR,INTGL,INTGR,ILP2,IRP2
*
*        LINEA Convert nonlinear (0-63) to linear (0-256).
*
      INTEGER      LINEA(0:64)
*
*        JBYT   CERNLIB function.
*        JBIT   CERNLIB function.
*        KRATE  FADC Crate number function.
*
      INTEGER      JBYT,JBIT,KRATE
*
*        FIRST  Identfy as first call.
*        LCLIP  Identify pulse as being clipped.
*        LRUN   Is this a run with sign bit internal checking?
*        LGL
*        LGR
*
      LOGICAL      FIRST,LCLIP,LRUN,LGL,LGR
*
*KEEP,CBLINK.
      INTEGER ZBLENG
      PARAMETER (ZBLENG = 600000)
      INTEGER XELENG, XCLENG, XLQLNG, XIQLNG
      PARAMETER (XELENG = 100000)
      PARAMETER (XCLENG = ZBLENG-XELENG)
      PARAMETER (XLQLNG = ZBLENG + 100)
      PARAMETER (XIQLNG = ZBLENG +  92)
*      COMMON /CBBANK/ FENCCB(16),LSTRUC(10),LREFER(90),XEVTCB(40 000),
*     &                XCONCB(150 000)
*      INTEGER FENCCB,LSTRUC,LREFER,  LQ(190 100), IQ(190 092)
*      REAL    XEVTCB,XCONCB,         Q(190 092)
      COMMON /CBBANK/ FENCCB(16),LSTRUC(10),LREFER(90),XEVTCB(XELENG),
     &                XCONCB(XCLENG)
      INTEGER FENCCB,LSTRUC,LREFER,  LQ(XLQLNG), IQ(XIQLNG)
      REAL    XEVTCB,XCONCB,         Q(XIQLNG)
      EQUIVALENCE (LSTRUC(1),LQ(1))
      EQUIVALENCE (LQ(9),IQ(1))
      EQUIVALENCE (LQ(9),Q(1))
*
*  header words
*
      INTEGER    MAXHD
      PARAMETER (MAXHD=30)
      COMMON/CBHEAD/NEHDCB,IEHDCB(MAXHD),NRHDCB,IRHDCB(MAXHD)
      INTEGER NEHDCB,IEHDCB,NRHDCB,IRHDCB
*
      COMMON /CBLINK/ LFRST,
     &   LEVHD,LHRAW,LHTJD,LHTBC,LHTRK,LHFIT,LHUSR,
     &   LRTRG,LRSFT,LRPWC,LRSCL,LRJDC,LRJDF,LRBCF,LRBCL,
     &   LRBCR,LRLAT,LRLPR,LRMON,LRENO,LRMCB,LRVTX,LRSVX,
     &   LDIST,LSWIT,LGEOM,LVERT,LKINE,LPHYS,LMCIN,LRTBF,LRTBL,
     &   LTJDC,LTPWC,LTCHT,LTCTK,LTCTR,LTCHX,LTCVX,LTVXT,
     &   LTBEF,LTBEL,LTBEN,LTBCL,LTBTK,
     &   LTVTX,LTTKS,LKRES,
     &   LUSR1,LUSR2,LUSR3,LUSR4,LUSR5,
     &   LSPR1,LSPR2,LSPR3,LSPR4,LSPR5,
     &   LCALB,
     &   LTJCE,LTJCT,LTJT0,LTJCZ,LTJZ0,LTJZL,LTJST,LTJCP,
     &   LTJSL,LTJSR,LTJSZ,
     &   LTJWR,LTJRF,LCJTF,LCJNF,LCJMX,
     &   LCLGE,LCBEF,LCBEL,LCBPF,LCBPL,LCBTF,LCBXF,LCBXL,
     &   LCBCL,LCBCF,LCBRF,LCBPC,LCBBS,LCBGE,LCBGN,LCBGM,LCBGO,
     &   LCCRN,LCCBF,LCCPR,LCCKL,
     &   LLAST

      COMMON /CBXDIV/IXCOMP,IXFRST,
     &   IXEVHD,IXHRAW,IXHTJD,IXHTBC,IXHTRK,IXHFIT,IXHUSR,
     &   IXRTRG,IXRSFT,IXRPWC,IXRSCL,IXRJDC,IXRJDF,IXRBCF,IXRBCL,
     &   IXRBCR,IXRLAT,IXRLPR,IXRMON,IXRENO,IXRMCB,IXRVTX,IXRSVX,
     &   IXDIST,IXSWIT,IXGEOM,IXVERT,IXKINE,IXPHYS,
     &   IXMCIN,IXRTBF,IXRTBL,
     &   IXTJDC,IXTPWC,IXTCHT,IXTCTK,IXTCTR,IXTCHX,IXTCVX,IXTVXT,
     &   IXTBEF,IXTBEL,IXTBEN,IXTBCL,IXTBTK,
     &   IXTVTX,IXTTKS,IXKRES,
     &   IXUSR1,IXUSR2,IXUSR3,IXUSR4,IXUSR5,
     &   IXSPR1,IXSPR2,IXSPR3,IXSPR4,IXSPR5,
     &   IXCALB,
     &   IXTJCE,IXTJCT,IXTJT0,IXTJCZ,IXTJZ0,IXTJZL,IXTJST,IXTJCP,
     &   IXTJSL,IXTJSR,IXTJSZ,
     &   IXTJWR,IXTJRF,IXCJTF,IXCJNF,IXCJMX,
     &   IXCLGE,IXCBEF,IXCBEL,IXCBPF,IXCBPL,IXCBTF,IXCBXF,IXCBXL,
     &   IXCBCL,IXCBCF,IXCBRF,IXCBPC,
     &   IXCCRN,IXCCBF,IXCCPR,IXCCKL,
     &   IXWORK,IXEVNT,IXCONS,IXSAVE,
     &   IXSTOR
      INTEGER        LFRST,
     &   LEVHD,LHRAW,LHTJD,LHTBC,LHTRK,LHFIT,LHUSR,
     &   LRTRG,LRSFT,LRPWC,LRSCL,LRJDC,LRJDF,LRBCF,LRBCL,
     &   LRBCR,LRLAT,LRLPR,LRMON,LRENO,LRMCB,LRVTX,LRSVX,
     &   LDIST,LSWIT,LGEOM,LVERT,LKINE,LPHYS,LMCIN,LRTBF,LRTBL,
     &   LTJDC,LTPWC,LTCHT,LTCTK,LTCTR,LTCHX,LTCVX,LTVXT,
     &   LTBEF,LTBEL,LTBEN,LTBCL,LTBTK,
     &   LTVTX,LTTKS,LKRES,
     &   LUSR1,LUSR2,LUSR3,LUSR4,LUSR5,
     &   LSPR1,LSPR2,LSPR3,LSPR4,LSPR5,
     &   LCALB,
     &   LTJCE,LTJCT,LTJT0,LTJCZ,LTJZ0,LTJZL,LTJST,LTJCP,
     &   LTJSL,LTJSR,LTJSZ,
     &   LTJWR,LTJRF,LCJTF,LCJNF,LCJMX,
     &   LCLGE,LCBEF,LCBEL,LCBPF,LCBPL,LCBTF,LCBXF,LCBXL,
     &   LCBCL,LCBCF,LCBRF,LCBPC,LCBBS,LCBGE,LCBGN,LCBGM,LCBGO,
     &   LCCRN,LCCBF,LCCPR,LCCKL,
     &   LLAST
      INTEGER        IXCOMP,IXFRST,
     &   IXEVHD,IXHRAW,IXHTJD,IXHTBC,IXHTRK,IXHFIT,IXHUSR,
     &   IXRTRG,IXRSFT,IXRPWC,IXRSCL,IXRJDC,IXRJDF,IXRBCF,IXRBCL,
     &   IXRBCR,IXRLAT,IXRLPR,IXRMON,IXRENO,IXRMCB,IXRVTX,IXRSVX,
     &   IXDIST,IXSWIT,IXGEOM,IXVERT,IXKINE,IXPHYS,
     &   IXMCIN,IXRTBF,IXRTBL,
     &   IXTJDC,IXTPWC,IXTCHT,IXTCTK,IXTCTR,IXTCHX,IXTCVX,IXTVXT,
     &   IXTBEF,IXTBEL,IXTBEN,IXTBCL,IXTBTK,
     &   IXTVTX,IXTTKS,IXKRES,
     &   IXUSR1,IXUSR2,IXUSR3,IXUSR4,IXUSR5,
     &   IXSPR1,IXSPR2,IXSPR3,IXSPR4,IXSPR5,
     &   IXCALB,
     &   IXTJCE,IXTJCT,IXTJT0,IXTJCZ,IXTJZ0,IXTJZL,IXTJST,IXTJCP,
     &   IXTJWR,IXTJRF,IXCJTF,IXCJNF,IXCJMX,
     &   IXTJSL,IXTJSR,IXTJSZ,
     &   IXCLGE,IXCBEF,IXCBEL,IXCBPF,IXCBPL,IXCBTF,IXCBXF,IXCBXL,
     &   IXCBCL,IXCBCF,IXCBRF,IXCBPC,
     &   IXCCRN,IXCCBF,IXCCPR,IXCCKL,
     &   IXWORK,IXEVNT,IXCONS,IXSAVE,
     &   IXSTOR
*KEEP,TCLIFT.
      INTEGER         MRJDC(5),MTJDC(5),MTJDS(5),MTCHT(5),MTCLY(5)
      INTEGER         MTCTK(5),MTCSG(5),MTCTR(5),MTCTX(5),MTCVH(5)
      INTEGER         MTCHX(5),MTCHP(5),MTCVX(5),MTCVT(5),MTCVP(5)
      INTEGER         MTPWC(5),MTPCH(5),MTPCL(5),MHTJD(5),MTJRF(5)
      INTEGER         MTJCT(5),MTJXX(5),MTJCP(5),MTJST(5),MTJT0(5)
      INTEGER         MTJCZ(5),MTJCE(5),MTJZ0(5),MTJZL(5),MTJWR(5)
      INTEGER         MTJSL(5),MTJSR(5),MTJSZ(5),MTVXT(5),MRSVX(5)
      INTEGER         MTSV1(5),MTSV2(5)
      COMMON /TCLIFT/ MRJDC,MTJDC,MTJDS,MTCHT,MTCLY
     &               ,MTCTK,MTCSG,MTCTR,MTCTX,MTCVH
     &               ,MTCHX,MTCHP,MTCVX,MTCVT,MTCVP
     &               ,MTPWC,MTPCH,MTPCL,MHTJD,MTJRF
     &               ,MTJCT,MTJXX,MTJCP,MTJST,MTJT0
     &               ,MTJCZ,MTJCE,MTJZ0,MTJZL,MTJWR
     &               ,MTJSL,MTJSR,MTJSZ,MTVXT,MRSVX
     &               ,MTSV1,MTSV2
      SAVE /TCLIFT/
*
*KEEP,CBUNIT.
      COMMON /CBUNIT/LDST,LRDT,LLOG,LPRNT,LTERM,LDBG,LERR,LNORM,LHST,
     &              LHYP,LTIME,LTIML,LJCAL,LJGAIN,LJTOUT,LJGOUT,LJRESI
      INTEGER LRDT,LDST,LLOG,LPRNT,LTERM,LDBG,LERR,LNORM,LHST
      INTEGER LHYP,LTIME,LTIML,LJCAL,LJGAIN,LJTOUT,LJGOUT,LJRESI
*KEEP,RJDATA.
*
*        NCHARJ Number of channels in the pulse.
*        ITOFRJ Time offset to first channel.
*        INTGRJ Integration width.
*        ILPDRJ Pedestal for the left channel.
*        IRPDRJ Pedestal for the right channel.
*        MINPRJ Start channel of pulse.
*        MAXPRJ Ending channel of pulse.
*        IENDRJ End of pulse.
*        IDTIRJ Drift time of pulses.
*
      INTEGER         NCHARJ,ITOFRJ,INTGRJ,ILPDRJ,IRPDRJ
      INTEGER         MINPRJ(0:5,2),MAXPRJ(0:5,2)
      INTEGER         IENDRJ(0:5,2),IDTIRJ(0:5,2)
      COMMON /RJDATA/ NCHARJ,ITOFRJ,INTGRJ,ILPDRJ,IRPDRJ,
     &                MINPRJ,MAXPRJ,IENDRJ,IDTIRJ
      SAVE   /RJDATA/
*
*KEEP,RJPRMS.
*
*        Contains cutoffs used in the RJPROC routines.
*        LGT0RJ  Identify if T0 should be subtracted.
*        LGPDRJ  Identify if pedestals are not dynamically computed.
*        LGRJDD  Choose online processed data if true.
*        LGRJDF  Reprocess raw data (RJDC) if true.
*        NPULRJ  Minimum amplitude for a pulse.
*        NTMIRJ  Minimum time separation.
*        ITIMRJ  Integration time.
*        MXPLRJ  Maximum time difference (l/r) for same pulse.
*        ITFCRJ  Time offset for each FADC crate.
*
      LOGICAL         LGT0RJ,LGPDRJ,LGRJDD,LGRJDF
      INTEGER         NPULRJ,NTMIRJ,ITIMRJ,MXPLRJ,ITFCRJ(16)
      COMMON /RJPRMS/ LGT0RJ,LGPDRJ,LGRJDD,LGRJDF
     &               ,NPULRJ,NTMIRJ,ITIMRJ,MXPLRJ,ITFCRJ
      SAVE   /RJPRMS/
*
*        ITCONV Number of nanoseconds per RJDC time units.
*        ISCAL  Convert FADC channels to RJDC time units.
*        IRLENG Lenght of the RJDC subblock in I*4 words.
*
      INTEGER    ITCONV,ISCAL,IRLENG
      PARAMETER (ITCONV=5,ISCAL=10*ITCONV,IRLENG=2)
*
*KEEP,TCSTAT.
*
*        This common block is used to keep track of what happened
*        during analysis of the JDC data. For a description of the
*        variables, consult the software manual.
*
      INTEGER         NSTATC,NSTKTC
      PARAMETER      (NSTATC=60,NSTKTC=60)
      INTEGER         ISTATC(NSTATC),ISTKTC(NSTKTC)
      COMMON /TCSTAT/ ISTATC,ISTKTC
      SAVE   /TCSTAT/
*
*KEND.
*
*
*        ISCAL  Conversion factor from FADC bins to time.
*        LEFT   Code for left side.
*        RIGHT  Code for right side.
*        MDATA  Nominal data in RJDC bank.
*        IRUNB  Run number after which sign bit is coded.
*        LIN40  Linearization of 40.
*
      INTEGER      LEFT,RIGHT,MDATA,IRUNB,LIN40
      PARAMETER   (LEFT=1,RIGHT=2,MDATA=5000,IRUNB=835)
      INTEGER      NONLIN
      PARAMETER   (NONLIN=8000)

      REAL RISER, RISEL
*
      SAVE  FIRST,LINEA,LIN40
*
      INTEGER IERHED,IERWOR,IERTMD,IERZEB,IE1023,IE0015
      SAVE    IERHED,IERWOR,IERTMD,IERZEB,IE1023,IE0015
*
      DATA  FIRST /.TRUE./
      DATA  LINEA /65*0/
      DATA  LIN40 /0/
*
      DATA  IERHED,IERWOR,IERTMD,IERZEB,IE1023,IE0015 /6*0/
*
*     _________________________________


*
*
      CALL RJCORR(IERR)
*
*


*
*        Check to see if this is a run with internal sign bit checking.
*
      LRUN = .FALSE.
      IF(IEHDCB(4).GT.IRUNB) LRUN = .TRUE.
*
      IERR = 0
      ICRAT = 0
*
      ISTATC(4) = ISTATC(4) + 1
*
*
*
*        On the first call to this routine, we want to create a lookup
*        table for unfolding amplitudes. Nonlinear 0-64 ==> Linear 0-256.
*
      IF(FIRST) THEN
         FIRST = .FALSE.
         LINEA(0) = 0
         DO 100 I = 1,64
            LINEA(I) = IFIX( FLOAT(I)*640. /
     &                     (64. - 0.7539*FLOAT(I)) + 0.5)
 100     CONTINUE
         DO 200 I = 1,63
            LINEA(I) = (LINEA(I+1) + LINEA(I))/2
 200     CONTINUE
         LIN40 = LINEA(40)
      ENDIF
*
*     Check to see if there is an RJDF or RJDG data bank. If not, then
*     we simply return.
*

      IRJDC = 0
      IF(LRJDC .GT. 0) IRJDC = LRJDC + 6
      IF(LRJDF .LE. 0) RETURN
      KRJDF = LRJDF
*
*        Get the header information from the RJDF bank. If the header
*        is not the corect RJDF header, then we want to exit.
*
 500  IF(IBITS(IQ(KRJDF+1),16,16) .NE. 65531  ) THEN
         ISTKTC(24) = ISTKTC(24) + 1
         CALL ERRLOG(IERHED,' <RJPROC> ERROR IN RJDF BANK HEADER ')
         IERR = 1
         RETURN
      ENDIF
*
*        Get the number of words in this bank. There have to be more than
*        three, as that is the length of a pulse header. Also, make sure
*        that this agrees with the zebra bank header. If not, tag as an
*        error, and exit.
*
      NWORD = IBITS(IQ(KRJDF+1),0,16)
      IF(NWORD .NE. IQ(KRJDF-1)) THEN
         ISTKTC(25) = ISTKTC(25) + 1
         CALL ERRLOG(IERWOR,' <RJPROC> ERROR IN RJDF WORD COUNT')
         IERR = 1
         RETURN
      ENDIF
*
      IF(NWORD .LE. 3) GOTO 2000
*
*        If no RJDC bank exists, then we want to create one. This
*        bank is lifted with a default of 5000 data words, which
*        will allow for roughly 2500 hits in the JDC.
*
      IF(LRJDC .LE. 0) THEN
         MRJDC(4) = MDATA
         CALL MZLIFT(IXRJDC,LRJDC,LHRAW,-3,MRJDC,-1)
         IRJDC = LRJDC + 6
      ENDIF
*
*        Initialize loop over the data. First set the RJDF pointer to
*        the start of the data, and then set the word count to one.
*
      IRJDF = KRJDF + 1
      IWORD = 1
*
*        Have we unpacked all data in this bank? If so, then move to
*        the next bank.
*
 600  IF(IWORD .GE. NWORD) GOTO 2000
*
*        This is the start of new pulse information. Unpack the header
*        for this pulse. For run numbers larger than xxx, the sign bit,
*        bit 16 has been set in the NCHARJ word. If this word is not
*        1, then it is necessary to loop through the data and try to
*        find a 1 in it.
*
      IF(LRUN) THEN
         IF(JBIT(IQ(IRJDF+1),32) .NE. 1) THEN
            ISTKTC(28) = ISTKTC(28) +  1
 700        IWORD = IWORD + 1
            IF(IWORD .GT. NWORD) GOTO 2000
            IRJDF = IRJDF + 1
            IF(JBIT(IQ(IRJDF+1),32) .NE. 1) GOTO 700
            ISTKTC(29) = ISTKTC(29) + 1
         ENDIF
      ENDIF
*
      NCHARJ = IBITS(IQ(IRJDF+1),16,15)
      LYSEC  = IBITS(IQ(IRJDF+1), 0,16)
      ITOFRJ = IBITS(IQ(IRJDF+2), 0,16)
      IRPDRJ = IBITS(IQ(IRJDF+3),16,16) + 5
      ILPDRJ = IBITS(IQ(IRJDF+3), 0,16) + 5
      ISEC = IBITS(LYSEC, 8, 8)
      ILYR = IBITS(LYSEC, 0, 8)
      ICRAT = KRATE(ISEC,ILYR)
*
      ISTKTC(23) = ISTKTC(23) + 1
*
*
*
*        Now check to see if this pulse will run beyond the end of
*        the data structure. If it will, then we will not unpack it.
*
      NDATA = (NCHARJ + 1)/2
      IWORD = IWORD + NDATA + 3
      IF(IWORD .GT. NWORD) THEN
         ISTKTC(26) = ISTKTC(26) + 1
         GOTO 2000
      ENDIF
*
*        Make sure that there are no more than 1024 words in this
*        pulse. If there are, then abort the event.
*
      IF(NCHARJ .GT. 1024) THEN
         ISTKTC(22) = ISTKTC(22) + 1
         IERR = -1
         RETURN
      ENDIF
*
      IRJDF = IRJDF + 3
*
*        If this pulse is shorter than 15 channels, then we will
*        ignore it.
*
*   D. Armstrong   reduce to 9 channels from 15
      IF(NCHARJ .LT. 9) THEN
         CALL ERRLOG(IE0015,
     &    ' <RJPROC> SHORT PULSE THROWN AWAY ')
         IRJDF = IRJDF + NDATA
         GOTO 600
      ENDIF
*
*        Check to see if there are 255/1023 channels in this pulse.
*        If there are, then ignore it, bug log the warnings.
*
      IF( ( (ICRAT.GE.13).AND.(NCHARJ.EQ.1023) ) .OR.
     &    ( (ICRAT.LT.13).AND.(NCHARJ.EQ. 255))) THEN
*
         ISTKTC(21) = ISTKTC(21) + 1
         CALL ERRLOG(IE1023,
     &       ' <RJPROC> RIDICULOUS PULSE LENGTH, 1023')
         IRJDF = IRJDF + NDATA
         GOTO 600
*
      ENDIF
*
*        Loop over the rest of the data, and load into the DATARJ
*        array. Also, linearize the data at the same time we are
*        loading it. Note that we always unpack an even number of
*        data words, which means we may occaisionly get an extra
*        word. However, we only search the number of real words
*        in this pulse, NI2. Note that if the pulse height is exactly
*        zero, it may be 63.
*
*
      DO 800 I = 1,NDATA
*
         JJ = I+I
         II = JJ-1
         IRJDF = IRJDF + 1
*
         IPULL(II) = IBITS(IQ(IRJDF),24, 6)
         IPULR(II) = IBITS(IQ(IRJDF),16, 6)
         IPULL(JJ) = IBITS(IQ(IRJDF), 8, 6)
         IPULR(JJ) = IBITS(IQ(IRJDF), 0, 6)
*
*           Check for overflow pulses:
*
         IF(I .GT. 1) THEN
            IF((IPULL(II).EQ.0).AND.(IPULL(II-1).GE.40)) THEN
               IPULL(II) = 63
            ENDIF
            IF((IPULR(II).EQ.0).AND.(IPULR(II-1).GE.40)) THEN
               IPULR(II) = 63
            ENDIF
         ENDIF
*
         IPULL(II) = LINEA(IPULL(II))
         IPULR(II) = LINEA(IPULR(II))
*
         IF((IPULL(JJ).EQ.0).AND.(IPULL(II).GE.40)) THEN
            IPULL(JJ) = 63
         ENDIF
         IF((IPULR(JJ).EQ.0).AND.(IPULR(II).GE.40)) THEN
            IPULR(JJ) = 63
         ENDIF
*
         IPULL(JJ) = LINEA(IPULL(JJ))
         IPULR(JJ) = LINEA(IPULR(JJ))
*
*
 800  CONTINUE
*
*        Set up the start of the pulse.
*
      IPULL(0) = IPULL(1)
      IPULR(0) = IPULR(1)
*
*        Compute the pedestals dynamically if desired.
*        (Note that it is only safe to do this when ITOFRJ is
*        larger than 5 chanels.
*
      IF(.NOT.LGPDRJ.AND.(ITOFRJ.GE.5)) THEN
*
*        Compute the sigma squared of the first three bins
*        on both the left and right side.
*
         IL  = (IPULL(1) + IPULL(2) + IPULL(3))/3
         IR  = (IPULR(1) + IPULR(2) + IPULR(3))/3
         ILP2 = (IPULL(1)**2 + IPULL(2)**2 + IPULL(3)**2)/3
         IRP2 = (IPULR(1)**2 + IPULR(2)**2 + IPULR(3)**2)/3
*
         ILP2 = IABS(ILP2 - IL*IL)
         IRP2 = IABS(IRP2 - IR*IR)
*
*           If both sigmas are small enough, then use these as the
*           pedestals. Otherwise we want the default values.
*
         IF((ILP2.LE.280).AND.(IRP2.LE.280)) THEN
            ILPDRJ = IL
            IRPDRJ = IR
         ENDIF
*
      ENDIF
*
* Correct for JDC AMPLIFIER non-linearity for big pulses:
*
      DO 850 I = 1,NDATA
         IPULL(I) = IPULL(I) + (IPULL(I)-ILPDRJ)**2/NONLIN
         IPULR(I) = IPULR(I) + (IPULR(I)-IRPDRJ)**2/NONLIN
 850  CONTINUE
*
*        Initialize the needed information in the RJDATA common block,
*        then use the RJPULS routine to find the number of pulses
*        on the left and right side of the wires.
*
      IAOFL       = 0
      IAOFR       = 0
      MINPRJ(0,1) = 0
      MINPRJ(0,2) = 0
      NLFT        = 0
      NRGT        = 0
*
*        Find pulses on the left and right sides:
*
      CALL RJPULS(LEFT ,NLFT,IPULL)
      CALL RJPULS(RIGHT,NRGT,IPULR)
*
*
*        Check to see that pulses were found on at least one side.
*
      IF((NLFT .LE. 0) .AND. (NRGT .LE. 0)) GOTO 600
*
*        Loop over the pulses on both sides, and form hits. Note that
*        the RJPULS routine has stored a pulse start for NLFT+1 and
*        NRGT+1 as the end of the pulse. It has also stored a drift
*        time of 5000 for these non-existant pulses. This means that
*        there is always "valid" data in the below search.
*
      IL = 1
      IR = 1
 1000 ITDIF = IDTIRJ(IL,LEFT) - IDTIRJ(IR,RIGHT)
*
      IF(IABS(ITDIF) .LT. MXPLRJ) THEN
*
*           We have a pulse on both the left and right sides which can be
*           matched.
*
         ITIML = IDTIRJ(IL, LEFT)
         ITIMR = IDTIRJ(IR,RIGHT)
*
         LGL = .FALSE.
         LGR = .FALSE.
*
*           Use the amplitude fitting routines to fit the left and
*           right amplitude.
*
         IBEGL = MINPRJ(IL,LEFT)
         IENDL = MINPRJ(IL+1,LEFT)
*
         IBEGR = MINPRJ(IR,RIGHT)
         IENDR = MINPRJ(IR+1,RIGHT)
*
         IL = IL + 1
         IR = IR + 1
*
      ELSE
*
*        Here the pulses were not close enough together to be the
*        same. We want to treat them separately here.
*
         IF(ITDIF .GT. 0) THEN
*
*              The pulse on the right side is first, then comes the one
*              on the left side.
*
            ITIMR = IDTIRJ(IR,RIGHT)
            ITIML = ITIMR
*
            LGR = .FALSE.
*
            IBEGR = MINPRJ(IR,RIGHT)
            IENDR = MINPRJ(IR+1,RIGHT)
*
            IBEGL = IBEGR
*
*              If the next pulse on the other side is within 100ns,
*              then we will merge these pulses.
*
            IF((ITDIF .GT. 100*ITCONV) .AND.
     &         (MINPRJ(IL,LEFT)-IBEGR .GE. 8)) THEN
               IENDL = MINPRJ(IL,LEFT)
               LGL   = .FALSE.
            ELSE
               IENDL = IENDR
               LGL   = .TRUE.
               IL    = MIN(IL,NLFT) + 1
            ENDIF
*
            IR = IR + 1
*
         ELSE
*
*              The pulse on the left side comes first.
*
            ITIML = IDTIRJ(IL,LEFT)
            ITIMR = ITIML
            LGL   = .FALSE.
*
            IBEGL = MINPRJ(IL,LEFT)
            IENDL = MINPRJ(IL+1,LEFT)
*
            IBEGR = IBEGL
            IF((ITDIF .LT. -100*ITCONV) .AND.
     &         (MINPRJ(IR,RIGHT)-IBEGL .GE. 8)) THEN
               IENDR = MINPRJ(IR,RIGHT)
               LGR   = .FALSE.
            ELSE
               IENDR = IENDL
               IR    = MIN(IR,NRGT) + 1
               LGR   = .TRUE.
            ENDIF
*
            IL = IL + 1
*
         ENDIF
*
      ENDIF
*
*        Has either pulse been clipped?
*
      LCLIP = .FALSE.
      IF((IENDL .LT. NCHARJ).OR.(IENDR .LT. NCHARJ))LCLIP=.TRUE.
*
*        Compute the integration time for this pulse.
*
      INTGL = MIN(ITIMRJ,IENDL-IBEGL+1)
      INTGR = MIN(ITIMRJ,IENDR-IBEGR+1)
      INTGRJ= MIN(INTGL,INTGR)
*
*        Make sure that the integration length is at least 100ns.
*        If it is shorter than this, we have probably made an error.
*
      IF((INTGRJ.LT.7) .AND. (IBEGL+INTGRJ.LT.NCHARJ) .AND.
     &   (IBEGR+INTGRJ.LT.NCHARJ)) THEN
*
         ISTKTC(27) = ISTKTC(27) + 1
*
      ELSE
*
*           Use the RJAFIT routine to integrate this pulse.
*
         CALL RJAFIT(LCLIP,IBEGL,IBEGR,IALFT,IARGT,
     &               IAOFL,IAOFR,IPULL,IPULR)
*
*           If the amplitude sum is larger than zero, then we will
*           compute the drift time as the amplitude weighted time.
*
*  m.d. 25/11/91  convert to real to guard against integer overflow
*                 cure the symptoms, but not the cause.
*

*
*   D. Armstrong  add a cut on pulses where the amplitude is
*   suspiciously small compared to the first few bins (the pedestal)
*   as these are often outliers riding on the tail of the true pulse
*
         IF(IPULL(1).NE.0 .AND. IPULR(1) .NE. 0) THEN
           RISER = FLOAT(IARGT)/FLOAT(IPULR(1))
           RISEL = FLOAT(IALFT)/FLOAT(IPULL(1))
           IF(RISER .LT. 7.5 .AND. RISEL. LT. 7.5) then
             IALFT = -1  ! drop hit
             IARGT = -1  ! drop hit
           END IF
         END IF

         IASUM = IALFT + IARGT
         IF(IASUM .GT. 0) THEN
            ITIME = INT( (FLOAT(ITIML)*FLOAT(IALFT) +
     >                    FLOAT(ITIMR)*FLOAT(IARGT)  )/FLOAT(IASUM))
         ELSE
            ITIME = (ITIML+ITIMR)/2
         ENDIF
*
*           Correct the time by the t_0 offset for the FADC. This varies
*           with the FADC crate number.
*
         ITIME = ITIME + ITOFRJ*ISCAL
         IF(LGT0RJ) ITIME = ITIME - IQ(LTJT0+ICRAT)
*
*           Store this hit, and then check for more hits on
*           this pulse.
*
*
          IF((ITIME .GE. 0) .AND. (IASUM.GT.0) .AND.
     &       (ITIME.LT.4500*ITCONV)) THEN
*
            CALL SBYT(ITIME,IQ(IRJDC), 1,16)
            CALL SBYT(LYSEC,IQ(IRJDC),17,16)
            CALL SBYT(IARGT,IQ(IRJDC+1), 1,16)
            CALL SBYT(IALFT,IQ(IRJDC+1),17,16)
            IRJDC = IRJDC + IRLENG
*
*              Check for a buffer overflow.
*
            IF(IRJDC .GE. LRJDC+MDATA-1) THEN
               CALL ERRLOG(IERTMD,' <RJPROC> TOO MUCH RJDF DATA ')
               ISTKTC(30) = ISTKTC(30) + 1
               GOTO 2100
            ENDIF
*
         ELSE
*
*              Here we didnt really find a pulse. In order to allow
*              for "pulse merging" over long times, we need to see
*              if either LGL or LGR are set:
*
            IF( (LGL) .AND. (IL .LE. NLFT) ) IL = IL - 1
            IF( (LGR) .AND. (IR .LE. NRGT) ) IR = IR - 1
*
         ENDIF
*
      ENDIF
*
*        Have we examined all pulses both left and right?
*
      IF((IL.LE.NLFT).OR.(IR.LE.NRGT)) GOTO 1000
*
*        Go back and get the next pulse.
*
      GOTO 600
*
*        Now check to see if there is another raw data bank in linear
*        structure with this bank. If so, then we go back and analyze
*        it as well.
*
 2000 KRJDF = LQ(KRJDF)
      IF(KRJDF .GT. 250000) THEN
         CALL ERRLOG(IERZEB,' <RJPROC> ZEBRA MEMORY OVERRUN')
         IERR = 1
         RETURN
      ENDIF
      IF(KRJDF .GT. 0) GOTO 500
*
*        All raw pulse banks have been examined. If there is no RJDC
*        bank then just exit. Otherwise, we want to shrink the RJDC
*        bank to its true size, and set up the header words in it.
*
 2100 IF(LRJDC .LE. 0) RETURN
*
      NDATA = IRJDC - LRJDC - MDATA
      CALL MZPUSH(IXRJDC,LRJDC,0,NDATA,'R')
*
*        Set up the header of the RJDC bank.
*
      NDATA = 2 * IQ(LRJDC-1)
      ICODE =65534
*
*        Number of data words, and Header code, (FFFD).
*
      CALL SBYT(NDATA,IQ(LRJDC+1),17,16)
      CALL SBYT(ICODE,IQ(LRJDC+1), 1,16)
*
*        Block sublength and time conversion.
*
      CALL SBYT(IRLENG,IQ(LRJDC+2),17,16)
      CALL SBYT(ITCONV,IQ(LRJDC+2), 1,16)
*
*        Data is NOT t0 subtracted.
*
      IQ(LRJDC+3) = 0
      IQ(LRJDC+4) = 0
      IF(.NOT.LGT0RJ) CALL SBYT(1,IQ(LRJDC+3),17,16)
      IF(.NOT.LGPDRJ) CALL SBYT(1,IQ(LRJDC+3), 1,16)
*
*        Format word, and number of data words.
*
      NDATA = NDATA - 9
      CALL SBYT(ICODE,IQ(LRJDC+5),17,16)
      CALL SBYT(NDATA,IQ(LRJDC+5), 1,16)
*
*
      RETURN
 8001 FORMAT(' *** ERROR IN RJDF BANK HEADER, RUN ',I6,
     &       ' EVENT ',I9)
 8002 FORMAT(' *** ERROR, RJDF WORD COUNT , RUN ',I6,' EVENT ',I9)
 8004 FORMAT(' *** WARNING, TOO MUCH RJDF DATA, ',I6,' EVENT ',I9)
 8005 FORMAT(' *** ERROR IN RUN ',I6,' EVENT ',I9,' ZEBRA MEMORY',
     &       ' OVERRUN.')

      END
*CMZU:  1.99/11 06/07/95  23.20.19  by  Curtis A. Meyer
*CMZU:  1.93/05 25/11/94  16.41.44  by  D.S.Armstrong
*CMZU:  1.50/17 04/12/91  16.54.33  by  Gunter Folger
*CMZ :          22/11/91  10.13.29  by  Michael Doser
*CMZ :  1.45/00 15/01/91  13.33.22  by  Curtis A. Meyer
*CMZ :  1.42/00 11/07/90  08.27.26  by  Curtis A. Meyer
*-- Author :
      SUBROUTINE RJPULS(ISIDE,NPULS,IPULS)
*
*        Author:        Curtis A Meyer
*
*        Creation date: 8 May, 1989.
*        Modified:      4 April, 1990.
*
*        References:    Online routine PULSDF by G. Eckerlin.
*
*        Description:   This routine will search through the pulse
*                       passed in the IPULS array, and locate pulses.
*                       The number of found pulses will be returned
*                       as NPULS, while other pulse information is
*                       stored in the RJDATA common block. The important
*                       numbers are where each pulse starts, where the
*                       maximum channel is, and what the drift time is.
*                       The drift time is computed using a first electron
*                       algorithem. A line is fit to the rising edge of
*                       the pulse from the start bin+1 for either 6 channels,
*                       or to the maximum bin-1, (which ever comes first).
*                       The intercept of this line with the pedestal,
*                       (the start channel for second pulses) is defined
*                       as the drift time.
*
*        Called By:     RJPROC
*
*        Subroutines Referenced:
*
*        Edit History:  4 April, 1990 C.A.Meyer
*                       Expanded the RJTFIT function inline to speed up
*                       pulse processing. Also changed the timing
*                       algorithem from a bin of maxiumum difference to
*                       a first electron method. Also, the time units
*                       have been changed to 200ps from 1ns per channel.
*
*                       21 Nov, 1991 M. Doser
*                       convert central part from integer to real arithmetic
*                       to guard against overflows; remove the previous
*                       kludge which (mostly) guarded against integer
*                       overflows.
*                       limit NPULS to within the array limits of 5.
*
*     ***************************************************************
*
*KEEP,IMPNONE,IF=-F77.
      IMPLICIT NONE
*KEND.
*
*        Passed variables:
*        ISIDE  1=left,2=right.
*        NPULS  number of found pulses in the array.
*        IPULS  The array containg the pulse to search.
*
      INTEGER    ISIDE,NPULS,IPULS(0:*)
*
*        Internal variables:
*
*        LRISE  is the pulse rising?
*        LFALL  is it falling after reaching a maximum?
*
      LOGICAL    LRISE,LFALL
*
*        I,J    loop index.
*        ICH1   Contents of channel 1.
*        ICH2   Contents of channel 2.
*        ICH3
*        IDIF1  Difference between channels.
*        IDIF2
*
      INTEGER    I,J,ICH1,ICH2,ICH3,IDIF1,IDIF2
*
*        IPMAX  Bin containing the pulse maximum.
*        IPMIN  Bin containing the pulse minimum.
*        IXPLS  Previous maximum.
*        IPED    Pedestal plus  5 channels.
*        IPDD    Pedestal for second pulses.
*        ITIME   Fit drift time.
*
      INTEGER    IPMAX,IPMIN,IXPLS,IPED,IPDD,ITIME
*
*        NCH   Number of channels used in time fit.
*        ISA   Sum of amplitudes.
*        IST   Sum of times.
*        ISAT  Sum of amplitude times time.
*        ISA2  Sum of amplitudes squared.
*        IDEL  NCH*ISA2 - ISA*ISA
*        IALPH ISA2*IST - ISA*ISAT
*        IBETA NCH*ISAT - ISA*IST
*
      INTEGER    NCH,ISA,IST,ISAT,ISA2,IDEL,IALPH,IBETA
      REAL       DEL,ALPH,BETA
*
*KEEP,RJDATA.
*
*        NCHARJ Number of channels in the pulse.
*        ITOFRJ Time offset to first channel.
*        INTGRJ Integration width.
*        ILPDRJ Pedestal for the left channel.
*        IRPDRJ Pedestal for the right channel.
*        MINPRJ Start channel of pulse.
*        MAXPRJ Ending channel of pulse.
*        IENDRJ End of pulse.
*        IDTIRJ Drift time of pulses.
*
      INTEGER         NCHARJ,ITOFRJ,INTGRJ,ILPDRJ,IRPDRJ
      INTEGER         MINPRJ(0:5,2),MAXPRJ(0:5,2)
      INTEGER         IENDRJ(0:5,2),IDTIRJ(0:5,2)
      COMMON /RJDATA/ NCHARJ,ITOFRJ,INTGRJ,ILPDRJ,IRPDRJ,
     &                MINPRJ,MAXPRJ,IENDRJ,IDTIRJ
      SAVE   /RJDATA/
*
*KEEP,RJPRMS.
*
*        Contains cutoffs used in the RJPROC routines.
*        LGT0RJ  Identify if T0 should be subtracted.
*        LGPDRJ  Identify if pedestals are not dynamically computed.
*        LGRJDD  Choose online processed data if true.
*        LGRJDF  Reprocess raw data (RJDC) if true.
*        NPULRJ  Minimum amplitude for a pulse.
*        NTMIRJ  Minimum time separation.
*        ITIMRJ  Integration time.
*        MXPLRJ  Maximum time difference (l/r) for same pulse.
*        ITFCRJ  Time offset for each FADC crate.
*
      LOGICAL         LGT0RJ,LGPDRJ,LGRJDD,LGRJDF
      INTEGER         NPULRJ,NTMIRJ,ITIMRJ,MXPLRJ,ITFCRJ(16)
      COMMON /RJPRMS/ LGT0RJ,LGPDRJ,LGRJDD,LGRJDF
     &               ,NPULRJ,NTMIRJ,ITIMRJ,MXPLRJ,ITFCRJ
      SAVE   /RJPRMS/
*
*        ITCONV Number of nanoseconds per RJDC time units.
*        ISCAL  Convert FADC channels to RJDC time units.
*        IRLENG Lenght of the RJDC subblock in I*4 words.
*
      INTEGER    ITCONV,ISCAL,IRLENG
      PARAMETER (ITCONV=5,ISCAL=10*ITCONV,IRLENG=2)
*
*KEND.
*
*     ______________________________
*
      IF(ISIDE .EQ. 1) THEN
         IPED = ILPDRJ +  5
      ELSE
         IPED = IRPDRJ +  5
      ENDIF
*
*
*
*        Initialize the pulse search:
*
      LRISE = .FALSE.
      NPULS = 0
      IXPLS = 0
      IPMAX = 1
      IPMIN = 0
      IPDD  = IPED
      ICH1  = IPULS(0)
      ICH2  = IPULS(1)
      IDIF1 = 0
*
*        Loop over the data on the wire.
*
      DO 1000 I = 2,NCHARJ
*
         ICH3  = IPULS(I)
         IDIF2 = ICH3 - ICH2
         IF(.NOT.LRISE) IPMIN = I - 2
*
*
*    D. Armstrong -  grab the early risers!
         IF(I.EQ.2 .AND. (IDIF2.GT.NPULRJ) ) THEN
            IPMAX  = I
            LRISE  = .TRUE.
         END IF
*           Is the difference positive? If so then identify ICH2 as the
*           maximum of the pulse, and see if the maximum difference has
*           been found?
*
         IF(((IDIF1.GT.0) .AND. (IDIF2.GE.0)).OR.
     &      (LRISE.AND.(IDIF1.GE.0).AND.(IDIF2.GT.0))) THEN
*
            IPMAX  = I
            LRISE  = .TRUE.
*
*              Otherwise, we have reached the pulse maximum.
*
         ELSE
*
            IF(LRISE) THEN
*
*
*                 Check to make sure that the pulse was large enough,
*                 it must be NPULRJ channels above pedestal and at
*                 least 3 channels long.
*
               IF((IPULS(IPMAX)-IPULS(IPMIN).GE.NPULRJ).AND.
     &            (IPMAX-IPMIN).GE.2) THEN
*
*
*                    It also can be no closer than NTMIRJ channels to
*                    the previous pulse, if any.
*
                  LRISE = .FALSE.
                  IF((NPULS .EQ. 0) .OR.
     &               ((IPMAX-MAXPRJ(NPULS,ISIDE).GT.NTMIRJ).AND.
     &                (IPULS(IPMAX) .GE. IXPLS))) THEN
*
*                       Fit the time on this pulse. If it is negative,
*                       then we didn't really find a pulse.
*
                     IF(NPULS .GE. 4) GOTO 1100
*
                     IF(NPULS.GT.0)IPDD = MAX(IPED,IPULS(IPMIN))
*
*                       Fit the pulse time using the first electron
*                       method.
*
                     NCH  = MIN(6,MAX(2,IPMAX-IPMIN-1))
                     ISA  = 0
                     IST  = 0
                     ISAT = 0
                     ISA2 = 0
*
                     DO 500 J = 1,NCH
                        ISA  = ISA  + IPULS(IPMIN+J)
                        IST  = IST  + J
                        ISAT = ISAT + J*IPULS(IPMIN+J)
                        ISA2 = ISA2 + IPULS(IPMIN+J)*IPULS(IPMIN+J)
 500                 CONTINUE
*
                     IDEL = NCH*ISA2 - ISA*ISA
                     DEL = FLOAT(NCH)*FLOAT(ISA2) -FLOAT(ISA)*FLOAT(ISA)
                     IF(ABS(DEL) .GE. 1.E-7) THEN
*
                        ALPH = FLOAT(ISA2)*FLOAT(IST) -
     >                         FLOAT(ISA)*FLOAT(ISAT)
                        BETA = FLOAT(NCH)*FLOAT(ISAT) -
     >                         FLOAT(ISA)*FLOAT(IST)
*
                        ITIME = INT(ISCAL*(ALPH + IPDD*BETA)/DEL)
                        ITIME = ITIME + IPMIN*ISCAL
                        IF((NPULS.EQ.0) .OR. (ITIME -IDTIRJ
     &                     (NPULS,ISIDE) .GT. 80*ITCONV)) THEN
*
*
                           NPULS = NPULS + 1
*  keep NPULS to within the array limits
                           NPULS = MIN(NPULS,5)
                           MINPRJ(NPULS,ISIDE) = IPMIN
                           MAXPRJ(NPULS,ISIDE) = IPMAX
                           IDTIRJ(NPULS,ISIDE) = ITIME
*
                           IXPLS = (IPULS(IPMAX)*8)/10
*
                        ENDIF
                     ENDIF
                  ENDIF
               ENDIF
*
*                 Check to see if we have found two falling edges.
*
               IF((IDIF1.LT.0).OR.(IDIF2.LT.0).OR.(ICH2.LT.IPED)
     &         .OR.(ICH3.LE.IPED)) LRISE = .FALSE.
*
            ENDIF
         ENDIF
*
         ICH1  = ICH2
         ICH2  = ICH3
         IDIF1 = IDIF2
*
 1000 CONTINUE
*
 1100 NPULS = MIN(NPULS,4)
      IDTIRJ(NPULS+1,ISIDE) = 1024*ISCAL
      MINPRJ(NPULS+1,ISIDE) = NCHARJ
*
      RETURN
      END
*CMZU:  1.99/11 06/07/95  23.20.21  by  Curtis A. Meyer
*CMZU:  1.99/07 22/06/95  11.23.33  by  Christian Voelcker
*CMZ :  1.95/00 06/03/95  18.05.39  by  Christian Voelcker
*-- Author :  David S. Armstrong
      SUBROUTINE RJCORR(IERR)
*

*        Description:   This routine will take the unprocessed RJDF
*                       data, and correct for the mis-wired connector
*                       for sector 24, downstream, layers 7-12, for
*                       the new JDC; this hardware problem was
*                       corrected after the Nov 94 run.
*
*        Called by : RJPROC
*
*        (based on the RJPROC routine written by Curtis Meyer)
*
*        The technique is to load all the relevant data from the RJDF
*         bank for the affected wires into temporary arrays, then
*         go over the whole RJDF bank again and overwrite the
*         data onto the correct channel; i.e. we overwrite:
*
*           layer 7 downstream with data from "layer 6 downstream"
*           layer 8 downstream with data from "layer 7 downstream"
*           layer 9 downstream with data from "layer 8 downstream"
*           layer 10 downstream with data from "layer 9 downstream"
*           layer 11 downstream with data from "layer 10 downstream"
*           layer 12 downstream with data from "layer 11 downstream"
*                  (downstream = "left" side)
*
*    We don't zero out layer 6 downstream, since this layer is ignored
*     by the tracking software for the new JDC anyway
*
*         The overwriting is done so that the RJDF bank is not changed in
*    size, and so that the number of channels from each pulse is not
*    increased. In some cases this means only a truncated part of the
*    overwritten pulse is used; where necessary the trailing and/or
*    leading channels of the overwritten pulse are padded out with
*    pedestal values. The start of the superimposed pulse is adjusted
*    to compensate if it did not have the same time-offset as the
*    upstream (correct) side.
*
*        At the moment, I don't superimpose if the two pulses (upstream
*    and downstream ) are in different RJDF banks
*
*
*KEEP,IMPNONE,IF=-F77.
      IMPLICIT NONE
*KEND.
*
*        Passed variables:
*        IERR  Returned as zero for successful operation.
*
      INTEGER  IERR, ILNEW
*
*        Internal variables:
*        IRJDF  Internal pointer to the RJDF data bank.
*        KRJDF  Bank pointer, either RJDF or RGDG.
*
      INTEGER      IRJDF,KRJDF
*
*        I,J      Loop indicies

      INTEGER   I,J
*
*        IPULR   The raw pulse on the right side.
*        IPULL   The raw pulse on the left  side.
*
      INTEGER   IPULR(23,0:1024),IPULL(23,0:1024)
*
*        IWORD  Word count.
*        NWORD  Number of I*4 words in the RJDF data bank.
*        LYSEC  The Layer/sector coded for this hit.
*        ILYR   Layer number.
*        ISEC   Sector number.
*
      INTEGER   IWORD,NWORD,LYSEC,II,JJ,ILYR,ISEC,ITDIF
*
*
      INTEGER NDATA
*
*        IL,IR  Loop indicies over left and right pulses.
*
      INTEGER   IL,IR
*
*
*        JBYT   CERNLIB function.
*        JBIT   CERNLIB function.
*
      INTEGER      JBYT,JBIT
*
*
      INTEGER NCHANS(23),ITIMOF(23),IPEDL(23)
*
*
*        NCHANS  The number of channels of data in the stored pulse
*        ITIMOF  The time offset to the start of the stored pulse
*        IPEDL   The left (downstream) pedestal for strored pulse
*
      SAVE NCHANS, ITIMOF, IPEDL
*
*KEEP,CBLINK.
      INTEGER ZBLENG
      PARAMETER (ZBLENG = 600000)
      INTEGER XELENG, XCLENG, XLQLNG, XIQLNG
      PARAMETER (XELENG = 100000)
      PARAMETER (XCLENG = ZBLENG-XELENG)
      PARAMETER (XLQLNG = ZBLENG + 100)
      PARAMETER (XIQLNG = ZBLENG +  92)
*      COMMON /CBBANK/ FENCCB(16),LSTRUC(10),LREFER(90),XEVTCB(40 000),
*     &                XCONCB(150 000)
*      INTEGER FENCCB,LSTRUC,LREFER,  LQ(190 100), IQ(190 092)
*      REAL    XEVTCB,XCONCB,         Q(190 092)
      COMMON /CBBANK/ FENCCB(16),LSTRUC(10),LREFER(90),XEVTCB(XELENG),
     &                XCONCB(XCLENG)
      INTEGER FENCCB,LSTRUC,LREFER,  LQ(XLQLNG), IQ(XIQLNG)
      REAL    XEVTCB,XCONCB,         Q(XIQLNG)
      EQUIVALENCE (LSTRUC(1),LQ(1))
      EQUIVALENCE (LQ(9),IQ(1))
      EQUIVALENCE (LQ(9),Q(1))
*
*  header words
*
      INTEGER    MAXHD
      PARAMETER (MAXHD=30)
      COMMON/CBHEAD/NEHDCB,IEHDCB(MAXHD),NRHDCB,IRHDCB(MAXHD)
      INTEGER NEHDCB,IEHDCB,NRHDCB,IRHDCB
*
      COMMON /CBLINK/ LFRST,
     &   LEVHD,LHRAW,LHTJD,LHTBC,LHTRK,LHFIT,LHUSR,
     &   LRTRG,LRSFT,LRPWC,LRSCL,LRJDC,LRJDF,LRBCF,LRBCL,
     &   LRBCR,LRLAT,LRLPR,LRMON,LRENO,LRMCB,LRVTX,LRSVX,
     &   LDIST,LSWIT,LGEOM,LVERT,LKINE,LPHYS,LMCIN,LRTBF,LRTBL,
     &   LTJDC,LTPWC,LTCHT,LTCTK,LTCTR,LTCHX,LTCVX,LTVXT,
     &   LTBEF,LTBEL,LTBEN,LTBCL,LTBTK,
     &   LTVTX,LTTKS,LKRES,
     &   LUSR1,LUSR2,LUSR3,LUSR4,LUSR5,
     &   LSPR1,LSPR2,LSPR3,LSPR4,LSPR5,
     &   LCALB,
     &   LTJCE,LTJCT,LTJT0,LTJCZ,LTJZ0,LTJZL,LTJST,LTJCP,
     &   LTJSL,LTJSR,LTJSZ,
     &   LTJWR,LTJRF,LCJTF,LCJNF,LCJMX,
     &   LCLGE,LCBEF,LCBEL,LCBPF,LCBPL,LCBTF,LCBXF,LCBXL,
     &   LCBCL,LCBCF,LCBRF,LCBPC,LCBBS,LCBGE,LCBGN,LCBGM,LCBGO,
     &   LCCRN,LCCBF,LCCPR,LCCKL,
     &   LLAST

      COMMON /CBXDIV/IXCOMP,IXFRST,
     &   IXEVHD,IXHRAW,IXHTJD,IXHTBC,IXHTRK,IXHFIT,IXHUSR,
     &   IXRTRG,IXRSFT,IXRPWC,IXRSCL,IXRJDC,IXRJDF,IXRBCF,IXRBCL,
     &   IXRBCR,IXRLAT,IXRLPR,IXRMON,IXRENO,IXRMCB,IXRVTX,IXRSVX,
     &   IXDIST,IXSWIT,IXGEOM,IXVERT,IXKINE,IXPHYS,
     &   IXMCIN,IXRTBF,IXRTBL,
     &   IXTJDC,IXTPWC,IXTCHT,IXTCTK,IXTCTR,IXTCHX,IXTCVX,IXTVXT,
     &   IXTBEF,IXTBEL,IXTBEN,IXTBCL,IXTBTK,
     &   IXTVTX,IXTTKS,IXKRES,
     &   IXUSR1,IXUSR2,IXUSR3,IXUSR4,IXUSR5,
     &   IXSPR1,IXSPR2,IXSPR3,IXSPR4,IXSPR5,
     &   IXCALB,
     &   IXTJCE,IXTJCT,IXTJT0,IXTJCZ,IXTJZ0,IXTJZL,IXTJST,IXTJCP,
     &   IXTJSL,IXTJSR,IXTJSZ,
     &   IXTJWR,IXTJRF,IXCJTF,IXCJNF,IXCJMX,
     &   IXCLGE,IXCBEF,IXCBEL,IXCBPF,IXCBPL,IXCBTF,IXCBXF,IXCBXL,
     &   IXCBCL,IXCBCF,IXCBRF,IXCBPC,
     &   IXCCRN,IXCCBF,IXCCPR,IXCCKL,
     &   IXWORK,IXEVNT,IXCONS,IXSAVE,
     &   IXSTOR
      INTEGER        LFRST,
     &   LEVHD,LHRAW,LHTJD,LHTBC,LHTRK,LHFIT,LHUSR,
     &   LRTRG,LRSFT,LRPWC,LRSCL,LRJDC,LRJDF,LRBCF,LRBCL,
     &   LRBCR,LRLAT,LRLPR,LRMON,LRENO,LRMCB,LRVTX,LRSVX,
     &   LDIST,LSWIT,LGEOM,LVERT,LKINE,LPHYS,LMCIN,LRTBF,LRTBL,
     &   LTJDC,LTPWC,LTCHT,LTCTK,LTCTR,LTCHX,LTCVX,LTVXT,
     &   LTBEF,LTBEL,LTBEN,LTBCL,LTBTK,
     &   LTVTX,LTTKS,LKRES,
     &   LUSR1,LUSR2,LUSR3,LUSR4,LUSR5,
     &   LSPR1,LSPR2,LSPR3,LSPR4,LSPR5,
     &   LCALB,
     &   LTJCE,LTJCT,LTJT0,LTJCZ,LTJZ0,LTJZL,LTJST,LTJCP,
     &   LTJSL,LTJSR,LTJSZ,
     &   LTJWR,LTJRF,LCJTF,LCJNF,LCJMX,
     &   LCLGE,LCBEF,LCBEL,LCBPF,LCBPL,LCBTF,LCBXF,LCBXL,
     &   LCBCL,LCBCF,LCBRF,LCBPC,LCBBS,LCBGE,LCBGN,LCBGM,LCBGO,
     &   LCCRN,LCCBF,LCCPR,LCCKL,
     &   LLAST
      INTEGER        IXCOMP,IXFRST,
     &   IXEVHD,IXHRAW,IXHTJD,IXHTBC,IXHTRK,IXHFIT,IXHUSR,
     &   IXRTRG,IXRSFT,IXRPWC,IXRSCL,IXRJDC,IXRJDF,IXRBCF,IXRBCL,
     &   IXRBCR,IXRLAT,IXRLPR,IXRMON,IXRENO,IXRMCB,IXRVTX,IXRSVX,
     &   IXDIST,IXSWIT,IXGEOM,IXVERT,IXKINE,IXPHYS,
     &   IXMCIN,IXRTBF,IXRTBL,
     &   IXTJDC,IXTPWC,IXTCHT,IXTCTK,IXTCTR,IXTCHX,IXTCVX,IXTVXT,
     &   IXTBEF,IXTBEL,IXTBEN,IXTBCL,IXTBTK,
     &   IXTVTX,IXTTKS,IXKRES,
     &   IXUSR1,IXUSR2,IXUSR3,IXUSR4,IXUSR5,
     &   IXSPR1,IXSPR2,IXSPR3,IXSPR4,IXSPR5,
     &   IXCALB,
     &   IXTJCE,IXTJCT,IXTJT0,IXTJCZ,IXTJZ0,IXTJZL,IXTJST,IXTJCP,
     &   IXTJWR,IXTJRF,IXCJTF,IXCJNF,IXCJMX,
     &   IXTJSL,IXTJSR,IXTJSZ,
     &   IXCLGE,IXCBEF,IXCBEL,IXCBPF,IXCBPL,IXCBTF,IXCBXF,IXCBXL,
     &   IXCBCL,IXCBCF,IXCBRF,IXCBPC,
     &   IXCCRN,IXCCBF,IXCCPR,IXCCKL,
     &   IXWORK,IXEVNT,IXCONS,IXSAVE,
     &   IXSTOR
*KEEP,TCLIFT.
      INTEGER         MRJDC(5),MTJDC(5),MTJDS(5),MTCHT(5),MTCLY(5)
      INTEGER         MTCTK(5),MTCSG(5),MTCTR(5),MTCTX(5),MTCVH(5)
      INTEGER         MTCHX(5),MTCHP(5),MTCVX(5),MTCVT(5),MTCVP(5)
      INTEGER         MTPWC(5),MTPCH(5),MTPCL(5),MHTJD(5),MTJRF(5)
      INTEGER         MTJCT(5),MTJXX(5),MTJCP(5),MTJST(5),MTJT0(5)
      INTEGER         MTJCZ(5),MTJCE(5),MTJZ0(5),MTJZL(5),MTJWR(5)
      INTEGER         MTJSL(5),MTJSR(5),MTJSZ(5),MTVXT(5),MRSVX(5)
      INTEGER         MTSV1(5),MTSV2(5)
      COMMON /TCLIFT/ MRJDC,MTJDC,MTJDS,MTCHT,MTCLY
     &               ,MTCTK,MTCSG,MTCTR,MTCTX,MTCVH
     &               ,MTCHX,MTCHP,MTCVX,MTCVT,MTCVP
     &               ,MTPWC,MTPCH,MTPCL,MHTJD,MTJRF
     &               ,MTJCT,MTJXX,MTJCP,MTJST,MTJT0
     &               ,MTJCZ,MTJCE,MTJZ0,MTJZL,MTJWR
     &               ,MTJSL,MTJSR,MTJSZ,MTVXT,MRSVX
     &               ,MTSV1,MTSV2
      SAVE /TCLIFT/
*
*KEEP,CBUNIT.
      COMMON /CBUNIT/LDST,LRDT,LLOG,LPRNT,LTERM,LDBG,LERR,LNORM,LHST,
     &              LHYP,LTIME,LTIML,LJCAL,LJGAIN,LJTOUT,LJGOUT,LJRESI
      INTEGER LRDT,LDST,LLOG,LPRNT,LTERM,LDBG,LERR,LNORM,LHST
      INTEGER LHYP,LTIME,LTIML,LJCAL,LJGAIN,LJTOUT,LJGOUT,LJRESI
*KEEP,RJDATA.
*
*        NCHARJ Number of channels in the pulse.
*        ITOFRJ Time offset to first channel.
*        INTGRJ Integration width.
*        ILPDRJ Pedestal for the left channel.
*        IRPDRJ Pedestal for the right channel.
*        MINPRJ Start channel of pulse.
*        MAXPRJ Ending channel of pulse.
*        IENDRJ End of pulse.
*        IDTIRJ Drift time of pulses.
*
      INTEGER         NCHARJ,ITOFRJ,INTGRJ,ILPDRJ,IRPDRJ
      INTEGER         MINPRJ(0:5,2),MAXPRJ(0:5,2)
      INTEGER         IENDRJ(0:5,2),IDTIRJ(0:5,2)
      COMMON /RJDATA/ NCHARJ,ITOFRJ,INTGRJ,ILPDRJ,IRPDRJ,
     &                MINPRJ,MAXPRJ,IENDRJ,IDTIRJ
      SAVE   /RJDATA/
*
*KEEP,RJPRMS.
*
*        Contains cutoffs used in the RJPROC routines.
*        LGT0RJ  Identify if T0 should be subtracted.
*        LGPDRJ  Identify if pedestals are not dynamically computed.
*        LGRJDD  Choose online processed data if true.
*        LGRJDF  Reprocess raw data (RJDC) if true.
*        NPULRJ  Minimum amplitude for a pulse.
*        NTMIRJ  Minimum time separation.
*        ITIMRJ  Integration time.
*        MXPLRJ  Maximum time difference (l/r) for same pulse.
*        ITFCRJ  Time offset for each FADC crate.
*
      LOGICAL         LGT0RJ,LGPDRJ,LGRJDD,LGRJDF
      INTEGER         NPULRJ,NTMIRJ,ITIMRJ,MXPLRJ,ITFCRJ(16)
      COMMON /RJPRMS/ LGT0RJ,LGPDRJ,LGRJDD,LGRJDF
     &               ,NPULRJ,NTMIRJ,ITIMRJ,MXPLRJ,ITFCRJ
      SAVE   /RJPRMS/
*
*        ITCONV Number of nanoseconds per RJDC time units.
*        ISCAL  Convert FADC channels to RJDC time units.
*        IRLENG Lenght of the RJDC subblock in I*4 words.
*
      INTEGER    ITCONV,ISCAL,IRLENG
      PARAMETER (ITCONV=5,ISCAL=10*ITCONV,IRLENG=2)
*
*KEEP,TCSTAT.
*
*        This common block is used to keep track of what happened
*        during analysis of the JDC data. For a description of the
*        variables, consult the software manual.
*
      INTEGER         NSTATC,NSTKTC
      PARAMETER      (NSTATC=60,NSTKTC=60)
      INTEGER         ISTATC(NSTATC),ISTKTC(NSTKTC)
      COMMON /TCSTAT/ ISTATC,ISTKTC
      SAVE   /TCSTAT/
*
*KEEP,TCFLAG.
*
*        GPWCTC is a logical that indicates the PWC is being used.
*        TRAKTC Activate track finding.
*        RAWSTC Process the raw data in TCTRAK.
*        PATTTC Do pattern recognition in TCTRAK.
*        CIRCTC Activate circle fitting in TCTRAK.
*        HELXTC Activate helix fitting in TCTRAK.
*        VERTTC Activate vertex fitting in TCTRAK.
*        VER2TC Activate secondaty vertex search.
*        OLDJDC Select the old (true) or new (false) JDC.
*        RTRKTC Retrack the JDC data.
*        GVTXTC Activate routines for the silicon vertex detector.
*        RASHTC Enables the special fuzzy Radon patt. rec. for short tracks
*
      LOGICAL         GPWCTC,TRAKTC,RAWSTC,PATTTC,CIRCTC
      LOGICAL         HELXTC,VERTTC,VER2TC,OLDJDC,RTRKTC
      LOGICAL         GVTXTC,RASHTC
      COMMON /TCFLAG/ GPWCTC,TRAKTC,RAWSTC,PATTTC,CIRCTC,
     &                HELXTC,VERTTC,VER2TC,OLDJDC,RTRKTC,
     &                GVTXTC,RASHTC
      SAVE   /TCFLAG/
*
*KEND.
*
*
*        ISCAL  Conversion factor from FADC bins to time.
*        LEFT   Code for left side.
*        RIGHT  Code for right side.
*        MDATA  Nominal data in RJDC bank.
*        IRUNB  Run number after which sign bit is coded.
*
      INTEGER      LEFT,RIGHT,MDATA,IRUNB
      PARAMETER   (LEFT=1,RIGHT=2,MDATA=5000,IRUNB=835)
      INTEGER      NONLIN
      PARAMETER   (NONLIN=8000)

*

      INTEGER IERHED,IERWOR,IERTMD,IERZEB,IE1023,IE0015
      SAVE    IERHED,IERWOR,IERTMD,IERZEB,IE1023,IE0015
*
*
      DATA  IERHED,IERWOR,IERTMD,IERZEB,IE1023,IE0015 /6*0/
*
*     _________________________________
*
*
*   a safety check - this correction only used for the new JDC!
*
      IF (OLDJDC) RETURN
*
*   correction only needed for runs
*          21266 until 26674 (inclusive)

      IF (IEHDCB(4) .LT. 21266 .OR. IEHDCB(4) .GT. 26674) RETURN


      IERR = 0
*
*
      IF(LRJDF .LE. 0) RETURN
      KRJDF = LRJDF
*
*        Get the header information from the RJDF bank. If the header
*        is not the corect RJDF header, then we want to exit.
*
 500  IF(IBITS(IQ(KRJDF+1),16,16) .NE. 65531  ) THEN
         CALL ERRLOG(IERHED,' <RJCORR> ERROR IN RJDF BANK HEADER ')
         IERR = 1
         RETURN
      ENDIF
*
*        Get the number of words in this bank. There have to be more than
*        three, as that is the length of a pulse header. Also, make sure
*        that this agrees with the zebra bank header. If not, tag as an
*        error, and exit.
*
      NWORD = IBITS(IQ(KRJDF+1),0,16)
      IF(NWORD .NE. IQ(KRJDF-1)) THEN
         CALL ERRLOG(IERWOR,' <RJCORR> ERROR IN RJDF WORD COUNT')
         IERR = 1
         RETURN
      ENDIF
*
      IF(NWORD .LE. 3) GOTO 2000

*        Initialize loop over the data. First set the RJDF pointer to
*        the start of the data, and then set the word count to one.
*
      IRJDF = KRJDF + 1
      IWORD = 1
*
*        Have we unpacked all data in this bank? If so, then move to
*        the next bank.
*
 600  IF(IWORD .GE. NWORD) GOTO 2000
*
*        This is the start of new pulse information. Unpack the header
*        for this pulse.
*
*
      NCHARJ = IBITS(IQ(IRJDF+1),16,15)
      LYSEC  = IBITS(IQ(IRJDF+1), 0,16)
      ITOFRJ = IBITS(IQ(IRJDF+2), 0,16)
      IRPDRJ = IBITS(IQ(IRJDF+3),16,16) + 5
      ILPDRJ = IBITS(IQ(IRJDF+3), 0,16) + 5
      ISEC = IBITS(LYSEC, 8, 8)
      ILYR = IBITS(LYSEC, 0, 8)
*
*        Now check to see if this pulse will run beyond the end of
*        the data structure. If it will, then we will not unpack it.
*
      NDATA = (NCHARJ + 1)/2
      IWORD = IWORD + NDATA + 3
      IF(IWORD .GT. NWORD) THEN
         GOTO 2000
      ENDIF
*
*        Make sure that there are no more than 1024 words in this
*        pulse. If there are, then abort the event.
*
      IF(NCHARJ .GT. 1024) THEN
         IERR = -1
         RETURN
      ENDIF
*
      IRJDF = IRJDF + 3
*
*     Do we have one of the channels in the mismatched connector?
*       if so, store the information so we can shuffle it later
*

      IF ( ISEC.EQ.24 .AND. ILYR.GE.6 .AND. ILYR.LE.12 ) THEN
        NCHANS(ILYR) = NCHARJ
        ITIMOF(ILYR) = ITOFRJ
        IPEDL(ILYR) = ILPDRJ/10.  ! for now, forget non-linearity....
        DO 800 I = 1,NDATA
         JJ = I+I
         II = JJ-1
         IRJDF = IRJDF + 1
         IPULL(ILYR,II) = IBITS(IQ(IRJDF),24, 6)
         IPULR(ILYR,II) = IBITS(IQ(IRJDF),16, 6)
         IPULL(ILYR,JJ) = IBITS(IQ(IRJDF), 8, 6)
         IPULR(ILYR,JJ) = IBITS(IQ(IRJDF), 0, 6)

 800    CONTINUE
      ELSE
       IRJDF=IRJDF+NDATA
      END IF
*
*        Go back and get the next pulse.
*

      GOTO 600
*
*       All "special" channels in this bank have been stored
*
*        Now check to see if there is another raw data bank in linear
*        structure with this bank. If so, then we go back and analyze
*        it as well.
*
 2000 KRJDF = LQ(KRJDF)
      IF(KRJDF .GT. 250000) THEN
         CALL ERRLOG(IERZEB,' <RJCORR> ZEBRA MEMORY OVERRUN')
         IERR = 1
         RETURN
      ENDIF
      IF(KRJDF .GT. 0) GOTO 500
*
*        All raw pulse banks have been examined.
*        now, we need to shuffle them; to do so, we will again go
*        through the complete RJDF bank

      KRJDF = LRJDF

*
 501  NWORD = IBITS(IQ(KRJDF+1),0,16)
      IF(NWORD .LE. 3) GOTO 2001

*        Initialize loop over the data. First set the RJDF pointer to
*        the start of the data, and then set the word count to one.
*
      IRJDF = KRJDF + 1
      IWORD = 1
*
*        Have we corrected  all data in this bank? If so, then move to
*        the next bank.
*
 601  IF(IWORD .GE. NWORD) GOTO 2001

      NCHARJ = IBITS(IQ(IRJDF+1),16,15)
      LYSEC  = IBITS(IQ(IRJDF+1), 0,16)
      ITOFRJ = IBITS(IQ(IRJDF+2), 0,16)
      IRPDRJ = IBITS(IQ(IRJDF+3),16,16) + 5
      ILPDRJ = IBITS(IQ(IRJDF+3), 0,16) + 5
      ISEC = IBITS(LYSEC, 8, 8)
      ILYR = IBITS(LYSEC, 0, 8)
*
*        Now check to see if this pulse will run beyond the end of
*        the data structure. If it will, then we will not unpack it.
*
      NDATA = (NCHARJ + 1)/2
      IWORD = IWORD + NDATA + 3
      IF(IWORD .GT. NWORD) THEN
         GOTO 2001
      ENDIF
      IRJDF = IRJDF + 3
*
*    Now let's do our superimposing (shuffling) of data
*
*     we have to handle odd and even channels a bit differently
*     in the data we are overwriting, since we want the data packed
*     properly in the RJDF bank (two channels per word)

      IF (ISEC .EQ. 24 .AND. ILYR .GT. 6 .AND. ILYR .LT. 13) THEN
*
*   only needed for sector 24, layers 7-12
*
        ILNEW = ILYR - 1
        ITDIF = ITIMOF(ILNEW)-ITOFRJ
*
*  ITDIF is the time offset between pulses in FADC channels
*
        J= MAX(0,-ITDIF)
*
*  J+1 is the channel number in the old pulse to start from
*
        DO I = 1,NDATA      ! we rewrite all channels of this pulse
          IRJDF = IRJDF + 1
          JJ = I+1
          II = JJ-1

          IF (II.LT.ITDIF) THEN   ! pad beginning with pedestals
            CALL MVBITS(IPEDL(ILNEW),0,8,IQ(IRJDF),24)
          ELSE
            J = J+1
            IF (J.LE. NCHANS(ILNEW)) THEN
               CALL MVBITS(IPULL(ILNEW,J),0,8,IQ(IRJDF),24)
            ELSE                  ! pad ending with pedestals
               CALL MVBITS(IPEDL(ILNEW),0,8,IQ(IRJDF),24)
            END IF
          END IF

          IF (JJ.LT.ITDIF) THEN   ! pad beginning with pedestals
            CALL MVBITS(IPEDL(ILNEW),0,8,IQ(IRJDF),8)
          ELSE
            J = J+1
            IF (J.LE. NCHANS(ILNEW)) THEN
               CALL MVBITS(IPULL(ILNEW,J),0,8,IQ(IRJDF),8)
            ELSE                  ! pad ending with pedestals
               CALL MVBITS(IPEDL(ILNEW),0,8,IQ(IRJDF),8)
            END IF
          END IF

        END DO
      ELSE
          IRJDF = IRJDF + NDATA
      END IF

      GO TO 601
*
*     Now check to see if there is another raw data bank in linear
*     structure with this bank. If so, then we go back and shuffle
*     it as well.
*
 2001 KRJDF = LQ(KRJDF)
      IF(KRJDF .GT. 250000) THEN
         CALL ERRLOG(IERZEB,' <RJCORR> ZEBRA MEMORY OVERRUN')
         IERR = 1
         RETURN
      ENDIF
      IF(KRJDF .GT. 0) GOTO 501

      RETURN

 8001 FORMAT(' *** ERROR IN RJDF BANK HEADER, RUN ',I6,
     &       ' EVENT ',I9)
 8002 FORMAT(' *** ERROR, RJDF WORD COUNT , RUN ',I6,' EVENT ',I9)
 8004 FORMAT(' *** WARNING, TOO MUCH RJDF DATA, ',I6,' EVENT ',I9)
 8005 FORMAT(' *** ERROR IN RUN ',I6,' EVENT ',I9,' ZEBRA MEMORY',
     &       ' OVERRUN.')

      END

*CMZU:  1.99/11 06/07/95  23.20.17  by  Curtis A. Meyer
*CMZU:  1.60/05 07/02/94  14.41.48  by  R.BOSSINGHAM
*CMZU:  1.58/01 14/01/94  14.04.18  by  R.BOSSINGHAM
*CMZ :  1.54/00 24/09/93  12.02.13  by  Curtis A. Meyer
*CMZ :  1.53/00 17/09/93  11.11.19  by  Curtis A. Meyer
*CMZ :  1.45/00 15/01/91  13.33.21  by  Curtis A. Meyer
*CMZ :  1.42/00 11/07/90  08.27.27  by  Curtis A. Meyer
*-- Author :  Curtis A. Meyer
      SUBROUTINE RJAFIT(LCLIP,IBEGL,IBEGR,IALFT,IARGT,
     &                  IAOFL,IAOFR,LPULL,LPULR)
*
*        Author:        Curtis A Meyer
*
*        Creation date: 8 May, 1989
*        Modified     : 16 June,    1989.
*        Modified     : 30 October, 1989.
*        Modified     : 29 August,  1993.
*        Modified     : 23 September, 1993.
*        Modified     : 14 January, 1994
*        Modified     : 31 January, 1994
*
*        References:    Online routine AMP1 by H von der Schmitt.
*                                      ----
*        Description:   This routine will simultaneously integrate both
*                       the left and right pulse of the JDC raw hit.
*
*        Subroutines Referenced: RJPULS.
*
*        Edit History:  20 July, 1989 C.A. Meyer
*                       Made the pulse separation for a second pulse into
*                       a variable which can be modified, ISEPRJ.
*
*                       30 October, 1989 C.A.Meyer
*                       Major routine overhaul to speed things up.
*
*                       29 August, 1993 R.Bossingham
*                       Base charge division only on "reliable" channels,
*                       but scale to keep integral the same for particle ID.
*
*                       23 September, 1993 R.Bossingham
*                       Remove very small channels from left-right sums
*                       used for Z determination.
*
*                       14 January, 1994 R.Bossingham
*                       Correct for amplifier non-linearity w/empirical term.
*                       Allow amplitudes up to 2250 for charge division.
*
*                       07 February, 1994 R.Bossingham
*                       Move correction for JDC amplifier non-linearity
*                       to RJPROC, where it belongs.  Use the corrected
*                       amplitudes for charge division up to LPULMX=3000.
*
*     ***************************************************************
*
*KEEP,IMPNONE,IF=-F77.
      IMPLICIT NONE
*KEND.
*
*        Passed variables:
*        LCLIP  This pulse has been clipped.
*        IBEGL  Channel at which left integration starts.
*        IBEGR  Channel at which right integration starts.
*        LPULL  Linear left pulse.
*        LPULR  Linear right pulse.
*        IALFT  Left amplitude.
*        IARGT  Right amplitude.
*        IAOFL  Offset for second hit left.
*        IAOFR  Offset for second hit right.
*
*
      LOGICAL   LCLIP
      INTEGER   IBEGL,IBEGR,LPULL(0:*),LPULR(0:*)
      INTEGER   IALFT,IARGT,IAOFL,IAOFR
*
*        Internal variables:

*        I    Loop indicies
*        IAL  Used for clipped pulses.
*        IAR  Used for clipped pulses.
*
      INTEGER      I,IAL,IAR
*
*        INCOR  INCOR(i)/INSCA is the correction factor applied to
*        INSCA  clipped FADC pulses.
*
      INTEGER      INCOR(50),INSCA
*
*        INTLIM Last bin used to determine charge division ratio
*
      INTEGER IALFTC
      INTEGER IARGTC
      INTEGER INTLIM
      INTEGER LPLTMP, LPRTMP
      INTEGER LPULMN, LPULMX
*
      PARAMETER (INTLIM=21)
      PARAMETER (LPULMN=15)
      PARAMETER (LPULMX=3000)
*
      REAL SUMTC
      REAL FLFTC
      REAL FRGTC
*
      SAVE         INCOR,INSCA
*
*KEEP,RJPRMS.
*
*        Contains cutoffs used in the RJPROC routines.
*        LGT0RJ  Identify if T0 should be subtracted.
*        LGPDRJ  Identify if pedestals are not dynamically computed.
*        LGRJDD  Choose online processed data if true.
*        LGRJDF  Reprocess raw data (RJDC) if true.
*        NPULRJ  Minimum amplitude for a pulse.
*        NTMIRJ  Minimum time separation.
*        ITIMRJ  Integration time.
*        MXPLRJ  Maximum time difference (l/r) for same pulse.
*        ITFCRJ  Time offset for each FADC crate.
*
      LOGICAL         LGT0RJ,LGPDRJ,LGRJDD,LGRJDF
      INTEGER         NPULRJ,NTMIRJ,ITIMRJ,MXPLRJ,ITFCRJ(16)
      COMMON /RJPRMS/ LGT0RJ,LGPDRJ,LGRJDD,LGRJDF
     &               ,NPULRJ,NTMIRJ,ITIMRJ,MXPLRJ,ITFCRJ
      SAVE   /RJPRMS/
*
*        ITCONV Number of nanoseconds per RJDC time units.
*        ISCAL  Convert FADC channels to RJDC time units.
*        IRLENG Lenght of the RJDC subblock in I*4 words.
*
      INTEGER    ITCONV,ISCAL,IRLENG
      PARAMETER (ITCONV=5,ISCAL=10*ITCONV,IRLENG=2)
*
*KEEP,RJDATA.
*
*        NCHARJ Number of channels in the pulse.
*        ITOFRJ Time offset to first channel.
*        INTGRJ Integration width.
*        ILPDRJ Pedestal for the left channel.
*        IRPDRJ Pedestal for the right channel.
*        MINPRJ Start channel of pulse.
*        MAXPRJ Ending channel of pulse.
*        IENDRJ End of pulse.
*        IDTIRJ Drift time of pulses.
*
      INTEGER         NCHARJ,ITOFRJ,INTGRJ,ILPDRJ,IRPDRJ
      INTEGER         MINPRJ(0:5,2),MAXPRJ(0:5,2)
      INTEGER         IENDRJ(0:5,2),IDTIRJ(0:5,2)
      COMMON /RJDATA/ NCHARJ,ITOFRJ,INTGRJ,ILPDRJ,IRPDRJ,
     &                MINPRJ,MAXPRJ,IENDRJ,IDTIRJ
      SAVE   /RJDATA/
*
*KEND.
*
      DATA  INCOR /50*1024/
      DATA  INSCA / 1024 /
*
*     ______________________________
*
*        Initialize the returned amplitudes.
*
      IALFT = 0
      IARGT = 0
*
*        Initialize the summed amplitude not used for Z resolution
*
      IALFTC = 0
      IARGTC = 0
*
*
* For charge division information:
*
*     Eliminate zeroes (zeroes or overflows).
*     Eliminate bins below pedestal.
*     Eliminate bins at the noise level.
*     Do not add channels which may be in non-linear regime.
*     Do not add channels not near the isochrone intersection.
*
      DO 1000 I = 0,INTGRJ-1
*
*           Integrate the questionable bins of the right and left channels;
*           store the others separately.
*
         LPLTMP = LPULL(IBEGL+I) - ILPDRJ
         LPRTMP = LPULR(IBEGR+I) - IRPDRJ
         IF (LPLTMP.GE.0 .AND. LPRTMP.GE.0) THEN
            IF (LPLTMP.GT.LPULMX .OR. LPRTMP.GT.LPULMX
     &          .OR. (LPLTMP.LT.LPULMN .AND. LPRTMP.LT.LPULMN)
     &          .OR. I.GT.INTLIM) THEN
               IALFTC = IALFTC + LPLTMP
               IARGTC = IARGTC + LPRTMP
            ELSE
               IALFT = IALFT + LPLTMP
               IARGT = IARGT + LPRTMP
            ENDIF
         ENDIF
*
 1000  CONTINUE
*
* Keep the same total amplitude, but scale by the "reliable" part:
*
      SUMTC = FLOAT(IALFTC+IARGTC)
      IF (IALFT+IARGT.GT.0) THEN
         FLFTC = FLOAT(IALFT)/FLOAT(IALFT+IARGT)
         FRGTC = 1. - FLFTC
         IALFT = IALFT + IFIX(SUMTC*FLFTC+0.5)
         IARGT = IARGT + IFIX(SUMTC*FRGTC+0.5)
      ELSE
         IALFT = IALFTC
         IARGT = IARGTC
      ENDIF
*
*        Correct for the tails from earlier pulses.
*        After this step, the amplitudes are 10 times the amplitude.
*
      IALFT = IALFT - IAOFL
      IARGT = IARGT - IAOFR
*
      IAOFL = 0
      IAOFR = 0
*
*        Check to see if we integrated for the full time. Otherwise
*        we want to scale the amplitude up as the pulse has been
*        clipped.
*
      IF(LCLIP .AND.(INTGRJ .LT. ITIMRJ)) THEN
*
         IAL = (IALFT * INCOR(INTGRJ)) / INSCA
         IAR = (IARGT * INCOR(INTGRJ)) / INSCA
*
         IAOFL = IAL - IALFT
         IAOFR = IAR - IARGT
         IALFT = IAL
         IARGT = IAR
*
      ENDIF
*
*        Limit the individual amplitudes to be smaller than 65535,
*        the maximum range on 15 bits, and that it be positive.
*
      IALFT = MAX(0 , MIN(65535,IALFT) )
      IARGT = MAX(0 , MIN(65535,IARGT) )
*
      RETURN
      END
*CMZU:  1.99/11 06/07/95  23.45.53  by  Curtis A. Meyer
*CMZ :  1.45/00 15/01/91  13.50.21  by  Curtis A. Meyer
*CMZ :  1.42/00 11/07/90  08.27.17  by  Curtis A. Meyer
*-- Author :
      SUBROUTINE RJRJDC(LUN)
*
*        Author:        Curtis A Meyer
*
*        Creation date: 23 May, 1989
*
*        References:
*
*        Description:   This routine prints the data in the RJDC data
*                       bank in a readable format.
*
*     ********************************************************************
*
*KEEP,IMPNONE,IF=-F77.
      IMPLICIT NONE
*KEND.
*
*        Passed variables:
*        LUN Logical unit for I/O.
*
      INTEGER       LUN
*
*        Internal variables:
*        IRJDC Pointer to the RJDC bank.
*        NHITS the number of hits in the bank.
*        ISEC  the sector number.
*        ILYR  the layer number.
*        I,I2  loop indicies.
*        ITIM  Drift time.
*        IALF  Left amplitude.
*        IARG  Right amplitude.
*        ILEN  Length of subblock.
*        LTIM  Time conversion.
*
      INTEGER IRJDC,NHITS,ISEC,ILYR,I,I2,ITIM,IALF,IARG,ILEN,LTIM
*
      LOGICAL  LGT0,LGPD
*
*        JBYT   CERNLIB function.
*        KRATE  FADC Crate number function.
*        ICRAT  FADC Crate number.
*
      INTEGER     JBYT,KRATE,ICRAT
*
*KEEP,CBLINK.
      INTEGER ZBLENG
      PARAMETER (ZBLENG = 600000)
      INTEGER XELENG, XCLENG, XLQLNG, XIQLNG
      PARAMETER (XELENG = 100000)
      PARAMETER (XCLENG = ZBLENG-XELENG)
      PARAMETER (XLQLNG = ZBLENG + 100)
      PARAMETER (XIQLNG = ZBLENG +  92)
*      COMMON /CBBANK/ FENCCB(16),LSTRUC(10),LREFER(90),XEVTCB(40 000),
*     &                XCONCB(150 000)
*      INTEGER FENCCB,LSTRUC,LREFER,  LQ(190 100), IQ(190 092)
*      REAL    XEVTCB,XCONCB,         Q(190 092)
      COMMON /CBBANK/ FENCCB(16),LSTRUC(10),LREFER(90),XEVTCB(XELENG),
     &                XCONCB(XCLENG)
      INTEGER FENCCB,LSTRUC,LREFER,  LQ(XLQLNG), IQ(XIQLNG)
      REAL    XEVTCB,XCONCB,         Q(XIQLNG)
      EQUIVALENCE (LSTRUC(1),LQ(1))
      EQUIVALENCE (LQ(9),IQ(1))
      EQUIVALENCE (LQ(9),Q(1))
*
*  header words
*
      INTEGER    MAXHD
      PARAMETER (MAXHD=30)
      COMMON/CBHEAD/NEHDCB,IEHDCB(MAXHD),NRHDCB,IRHDCB(MAXHD)
      INTEGER NEHDCB,IEHDCB,NRHDCB,IRHDCB
*
      COMMON /CBLINK/ LFRST,
     &   LEVHD,LHRAW,LHTJD,LHTBC,LHTRK,LHFIT,LHUSR,
     &   LRTRG,LRSFT,LRPWC,LRSCL,LRJDC,LRJDF,LRBCF,LRBCL,
     &   LRBCR,LRLAT,LRLPR,LRMON,LRENO,LRMCB,LRVTX,LRSVX,
     &   LDIST,LSWIT,LGEOM,LVERT,LKINE,LPHYS,LMCIN,LRTBF,LRTBL,
     &   LTJDC,LTPWC,LTCHT,LTCTK,LTCTR,LTCHX,LTCVX,LTVXT,
     &   LTBEF,LTBEL,LTBEN,LTBCL,LTBTK,
     &   LTVTX,LTTKS,LKRES,
     &   LUSR1,LUSR2,LUSR3,LUSR4,LUSR5,
     &   LSPR1,LSPR2,LSPR3,LSPR4,LSPR5,
     &   LCALB,
     &   LTJCE,LTJCT,LTJT0,LTJCZ,LTJZ0,LTJZL,LTJST,LTJCP,
     &   LTJSL,LTJSR,LTJSZ,
     &   LTJWR,LTJRF,LCJTF,LCJNF,LCJMX,
     &   LCLGE,LCBEF,LCBEL,LCBPF,LCBPL,LCBTF,LCBXF,LCBXL,
     &   LCBCL,LCBCF,LCBRF,LCBPC,LCBBS,LCBGE,LCBGN,LCBGM,LCBGO,
     &   LCCRN,LCCBF,LCCPR,LCCKL,
     &   LLAST

      COMMON /CBXDIV/IXCOMP,IXFRST,
     &   IXEVHD,IXHRAW,IXHTJD,IXHTBC,IXHTRK,IXHFIT,IXHUSR,
     &   IXRTRG,IXRSFT,IXRPWC,IXRSCL,IXRJDC,IXRJDF,IXRBCF,IXRBCL,
     &   IXRBCR,IXRLAT,IXRLPR,IXRMON,IXRENO,IXRMCB,IXRVTX,IXRSVX,
     &   IXDIST,IXSWIT,IXGEOM,IXVERT,IXKINE,IXPHYS,
     &   IXMCIN,IXRTBF,IXRTBL,
     &   IXTJDC,IXTPWC,IXTCHT,IXTCTK,IXTCTR,IXTCHX,IXTCVX,IXTVXT,
     &   IXTBEF,IXTBEL,IXTBEN,IXTBCL,IXTBTK,
     &   IXTVTX,IXTTKS,IXKRES,
     &   IXUSR1,IXUSR2,IXUSR3,IXUSR4,IXUSR5,
     &   IXSPR1,IXSPR2,IXSPR3,IXSPR4,IXSPR5,
     &   IXCALB,
     &   IXTJCE,IXTJCT,IXTJT0,IXTJCZ,IXTJZ0,IXTJZL,IXTJST,IXTJCP,
     &   IXTJSL,IXTJSR,IXTJSZ,
     &   IXTJWR,IXTJRF,IXCJTF,IXCJNF,IXCJMX,
     &   IXCLGE,IXCBEF,IXCBEL,IXCBPF,IXCBPL,IXCBTF,IXCBXF,IXCBXL,
     &   IXCBCL,IXCBCF,IXCBRF,IXCBPC,
     &   IXCCRN,IXCCBF,IXCCPR,IXCCKL,
     &   IXWORK,IXEVNT,IXCONS,IXSAVE,
     &   IXSTOR
      INTEGER        LFRST,
     &   LEVHD,LHRAW,LHTJD,LHTBC,LHTRK,LHFIT,LHUSR,
     &   LRTRG,LRSFT,LRPWC,LRSCL,LRJDC,LRJDF,LRBCF,LRBCL,
     &   LRBCR,LRLAT,LRLPR,LRMON,LRENO,LRMCB,LRVTX,LRSVX,
     &   LDIST,LSWIT,LGEOM,LVERT,LKINE,LPHYS,LMCIN,LRTBF,LRTBL,
     &   LTJDC,LTPWC,LTCHT,LTCTK,LTCTR,LTCHX,LTCVX,LTVXT,
     &   LTBEF,LTBEL,LTBEN,LTBCL,LTBTK,
     &   LTVTX,LTTKS,LKRES,
     &   LUSR1,LUSR2,LUSR3,LUSR4,LUSR5,
     &   LSPR1,LSPR2,LSPR3,LSPR4,LSPR5,
     &   LCALB,
     &   LTJCE,LTJCT,LTJT0,LTJCZ,LTJZ0,LTJZL,LTJST,LTJCP,
     &   LTJSL,LTJSR,LTJSZ,
     &   LTJWR,LTJRF,LCJTF,LCJNF,LCJMX,
     &   LCLGE,LCBEF,LCBEL,LCBPF,LCBPL,LCBTF,LCBXF,LCBXL,
     &   LCBCL,LCBCF,LCBRF,LCBPC,LCBBS,LCBGE,LCBGN,LCBGM,LCBGO,
     &   LCCRN,LCCBF,LCCPR,LCCKL,
     &   LLAST
      INTEGER        IXCOMP,IXFRST,
     &   IXEVHD,IXHRAW,IXHTJD,IXHTBC,IXHTRK,IXHFIT,IXHUSR,
     &   IXRTRG,IXRSFT,IXRPWC,IXRSCL,IXRJDC,IXRJDF,IXRBCF,IXRBCL,
     &   IXRBCR,IXRLAT,IXRLPR,IXRMON,IXRENO,IXRMCB,IXRVTX,IXRSVX,
     &   IXDIST,IXSWIT,IXGEOM,IXVERT,IXKINE,IXPHYS,
     &   IXMCIN,IXRTBF,IXRTBL,
     &   IXTJDC,IXTPWC,IXTCHT,IXTCTK,IXTCTR,IXTCHX,IXTCVX,IXTVXT,
     &   IXTBEF,IXTBEL,IXTBEN,IXTBCL,IXTBTK,
     &   IXTVTX,IXTTKS,IXKRES,
     &   IXUSR1,IXUSR2,IXUSR3,IXUSR4,IXUSR5,
     &   IXSPR1,IXSPR2,IXSPR3,IXSPR4,IXSPR5,
     &   IXCALB,
     &   IXTJCE,IXTJCT,IXTJT0,IXTJCZ,IXTJZ0,IXTJZL,IXTJST,IXTJCP,
     &   IXTJWR,IXTJRF,IXCJTF,IXCJNF,IXCJMX,
     &   IXTJSL,IXTJSR,IXTJSZ,
     &   IXCLGE,IXCBEF,IXCBEL,IXCBPF,IXCBPL,IXCBTF,IXCBXF,IXCBXL,
     &   IXCBCL,IXCBCF,IXCBRF,IXCBPC,
     &   IXCCRN,IXCCBF,IXCCPR,IXCCKL,
     &   IXWORK,IXEVNT,IXCONS,IXSAVE,
     &   IXSTOR
*KEEP,RJPRMS.
*
*        Contains cutoffs used in the RJPROC routines.
*        LGT0RJ  Identify if T0 should be subtracted.
*        LGPDRJ  Identify if pedestals are not dynamically computed.
*        LGRJDD  Choose online processed data if true.
*        LGRJDF  Reprocess raw data (RJDC) if true.
*        NPULRJ  Minimum amplitude for a pulse.
*        NTMIRJ  Minimum time separation.
*        ITIMRJ  Integration time.
*        MXPLRJ  Maximum time difference (l/r) for same pulse.
*        ITFCRJ  Time offset for each FADC crate.
*
      LOGICAL         LGT0RJ,LGPDRJ,LGRJDD,LGRJDF
      INTEGER         NPULRJ,NTMIRJ,ITIMRJ,MXPLRJ,ITFCRJ(16)
      COMMON /RJPRMS/ LGT0RJ,LGPDRJ,LGRJDD,LGRJDF
     &               ,NPULRJ,NTMIRJ,ITIMRJ,MXPLRJ,ITFCRJ
      SAVE   /RJPRMS/
*
*        ITCONV Number of nanoseconds per RJDC time units.
*        ISCAL  Convert FADC channels to RJDC time units.
*        IRLENG Lenght of the RJDC subblock in I*4 words.
*
      INTEGER    ITCONV,ISCAL,IRLENG
      PARAMETER (ITCONV=5,ISCAL=10*ITCONV,IRLENG=2)
*
*KEND.
*
*     ___________________________________________
*
      WRITE(LUN,100)IEHDCB(4),IEHDCB(5),LRJDC
 100  FORMAT(' RJDC Bank, Run ',I6,' Event ',I9,' LRJDC ',I10)
*
      IF(LRJDC .LE. 0) RETURN
      IF(IQ(LRJDC-1) .LE. 0) RETURN
*
*        Print the bank header information:
*
      I    = JBYT(IQ(LRJDC+1),17,16)
      I2   = JBYT(IQ(LRJDC+1), 1,16)
      ILEN = JBYT(IQ(LRJDC+2),17,16)
      LTIM = JBYT(IQ(LRJDC+2), 1,16)
      LGT0 = .FALSE.
      LGPD = .FALSE.
      IF(JBYT(IQ(LRJDC+3),17,16).EQ.0) LGT0 = .TRUE.
      IF(JBYT(IQ(LRJDC+3), 1,16).EQ.0) LGPD = .TRUE.
      IF(ILEN .LE. 0) ILEN = 2
      IF(LTIM .LE. 0) LTIM = 1
      WRITE(LUN,130)I2,I,ILEN,LTIM,LGT0,LGPD
 130  FORMAT(' Header word ',Z8,' Number of wires ',I6,/,
     &       ' Block length',I8,' Time Conversion ',I6,/,
     &       ' T0 has been subtracted   ',L4,' normally .FALSE.',/,
     &       ' RJDF Pedestals were used ',L4,' normally .FALSE.')
*
*        Get the number of hits:
*
      I2    = JBYT(IQ(LRJDC+5),17,16)
      NHITS = JBYT(IQ(LRJDC+5), 1,16)
      WRITE(LUN,140)I2,NHITS
 140  FORMAT(' Format marker ',Z8,' Number of I*2 words :',I5)
*
      NHITS = (NHITS - 2)/4
      NHITS =  MIN0(NHITS,500)
*
      IRJDC = LRJDC + 5
*
      DO 1000 I = 1,NHITS
*
*           Extract the sector number of this hit, then make sure that
*           it is within range.
*
         ISEC = JBYT (IQ(IRJDC+1),25,8)
         IF((ISEC.LE.0).OR.(ISEC.GT.30)) GOTO 1000
*
*           Now extract the rest of the data in integer form on this hit.
*
         ILYR   = JBYT (IQ(IRJDC+1),17, 8)
         IF((ILYR .LE. 0).OR.(ILYR .GT. 23)) GOTO 1000
         ITIM  = JBYT (IQ(IRJDC+1), 1,16)/LTIM
         IARG  = JBYT (IQ(IRJDC+2),17,16)
         IALF  = JBYT (IQ(IRJDC+2), 1,16)
         IF(LGT0) THEN
            ICRAT = KRATE(ISEC,ILYR)
            WRITE(LUN,1100)ISEC,ILYR,ICRAT,ITIM,
     &                     ITIM-ITFCRJ(ICRAT),IALF,IARG
         ELSE
            WRITE(LUN,1110)ISEC,ILYR,ITIM,IALF,IARG
         ENDIF
*
         IRJDC = IRJDC + ILEN
*
 1000 CONTINUE
      RETURN
 1100 FORMAT(' sector:',I2,' layer:',I2,' crate ',I2,' time:',2I8,
     *       ' ampl:',I8,2X,I8)
 1110 FORMAT(' sector:',I3,' layer:',I3,' time:',I8,
     *       ' ampl:',I8,2X,I8)
      END
*CMZU:  1.99/11 06/07/95  23.45.53  by  Curtis A. Meyer
*CMZ :  1.50/18 13/12/91  10.08.26  by  Curtis A. Meyer
*CMZ :  1.45/00 15/01/91  13.50.21  by  Curtis A. Meyer
*CMZ :  1.42/00 11/07/90  08.27.17  by  Curtis A. Meyer
*-- Author :
      SUBROUTINE RJRJDF(LUN)
*
*        Author:        Curtis A Meyer
*
*        Creation date: 21 May, 1989
*        Modified:      13 December, 1991
*
*        References:
*
*        Description:   This routine will print the contents of the RJDF
*                       data bank on unit LUN.
*
*        Subroutines Referenced:
*
*        Edit History:  13 December 1991 --- C.A.Meyer
*                       Modify the routine to only extract 6 bits
*                       from each raw pulse. Also check for
*                       corrupted data by looking for higher
*                       order bits.
*
*     *******************************************************************
*
*KEEP,IMPNONE,IF=-F77.
      IMPLICIT NONE
*KEND.
*
*        Passed variables:
*        LUN  Logical unit for printing.
*
      INTEGER       LUN
*
*        Internal variables:
*        FIRST      First entry to program.
*
      LOGICAL       FIRST
*
*        NDATA Amount of data in the bank.
*        IRJDF Pointer into the RJDF data bank.
*        NI2   The number of I*2 words in the bank.
*        ICODE Code to identify data format.
*        NWORD The number of I*4 words in a given hit.
*        ITOF  Time offset for the hit.
*        IPDL  Left pedestal for the hit.
*        IPDR  Right pedestal for the hit.
*        ISEC  Sector number of the hit.
*        ILYR  Layer number of the hit.
*        I1..2l..r   Left/right amplitudes.
*        I     Loop index.
*        IDATA Count on the data read.
*        I2CNT Count on the number of I*2 words.
*
      INTEGER      NDATA,IRJDF,NI2,ICODE,NWORD,ITOF,IPDL,IPDR
      INTEGER      I1L,I2L,I1R,I2R,I,ISEC,ILYR,IDATA,I2CNT
*
*        LGCRPT Flag if data are corrupted.
*
      LOGICAL      LGCRPT
*
*        LINEA Array to linearize the data:
*
      INTEGER      LINEA(0:63)
*
*        JBYT Cernlib bit function:
*
      INTEGER      JBYT
*
*KEEP,CBLINK.
      INTEGER ZBLENG
      PARAMETER (ZBLENG = 600000)
      INTEGER XELENG, XCLENG, XLQLNG, XIQLNG
      PARAMETER (XELENG = 100000)
      PARAMETER (XCLENG = ZBLENG-XELENG)
      PARAMETER (XLQLNG = ZBLENG + 100)
      PARAMETER (XIQLNG = ZBLENG +  92)
*      COMMON /CBBANK/ FENCCB(16),LSTRUC(10),LREFER(90),XEVTCB(40 000),
*     &                XCONCB(150 000)
*      INTEGER FENCCB,LSTRUC,LREFER,  LQ(190 100), IQ(190 092)
*      REAL    XEVTCB,XCONCB,         Q(190 092)
      COMMON /CBBANK/ FENCCB(16),LSTRUC(10),LREFER(90),XEVTCB(XELENG),
     &                XCONCB(XCLENG)
      INTEGER FENCCB,LSTRUC,LREFER,  LQ(XLQLNG), IQ(XIQLNG)
      REAL    XEVTCB,XCONCB,         Q(XIQLNG)
      EQUIVALENCE (LSTRUC(1),LQ(1))
      EQUIVALENCE (LQ(9),IQ(1))
      EQUIVALENCE (LQ(9),Q(1))
*
*  header words
*
      INTEGER    MAXHD
      PARAMETER (MAXHD=30)
      COMMON/CBHEAD/NEHDCB,IEHDCB(MAXHD),NRHDCB,IRHDCB(MAXHD)
      INTEGER NEHDCB,IEHDCB,NRHDCB,IRHDCB
*
      COMMON /CBLINK/ LFRST,
     &   LEVHD,LHRAW,LHTJD,LHTBC,LHTRK,LHFIT,LHUSR,
     &   LRTRG,LRSFT,LRPWC,LRSCL,LRJDC,LRJDF,LRBCF,LRBCL,
     &   LRBCR,LRLAT,LRLPR,LRMON,LRENO,LRMCB,LRVTX,LRSVX,
     &   LDIST,LSWIT,LGEOM,LVERT,LKINE,LPHYS,LMCIN,LRTBF,LRTBL,
     &   LTJDC,LTPWC,LTCHT,LTCTK,LTCTR,LTCHX,LTCVX,LTVXT,
     &   LTBEF,LTBEL,LTBEN,LTBCL,LTBTK,
     &   LTVTX,LTTKS,LKRES,
     &   LUSR1,LUSR2,LUSR3,LUSR4,LUSR5,
     &   LSPR1,LSPR2,LSPR3,LSPR4,LSPR5,
     &   LCALB,
     &   LTJCE,LTJCT,LTJT0,LTJCZ,LTJZ0,LTJZL,LTJST,LTJCP,
     &   LTJSL,LTJSR,LTJSZ,
     &   LTJWR,LTJRF,LCJTF,LCJNF,LCJMX,
     &   LCLGE,LCBEF,LCBEL,LCBPF,LCBPL,LCBTF,LCBXF,LCBXL,
     &   LCBCL,LCBCF,LCBRF,LCBPC,LCBBS,LCBGE,LCBGN,LCBGM,LCBGO,
     &   LCCRN,LCCBF,LCCPR,LCCKL,
     &   LLAST

      COMMON /CBXDIV/IXCOMP,IXFRST,
     &   IXEVHD,IXHRAW,IXHTJD,IXHTBC,IXHTRK,IXHFIT,IXHUSR,
     &   IXRTRG,IXRSFT,IXRPWC,IXRSCL,IXRJDC,IXRJDF,IXRBCF,IXRBCL,
     &   IXRBCR,IXRLAT,IXRLPR,IXRMON,IXRENO,IXRMCB,IXRVTX,IXRSVX,
     &   IXDIST,IXSWIT,IXGEOM,IXVERT,IXKINE,IXPHYS,
     &   IXMCIN,IXRTBF,IXRTBL,
     &   IXTJDC,IXTPWC,IXTCHT,IXTCTK,IXTCTR,IXTCHX,IXTCVX,IXTVXT,
     &   IXTBEF,IXTBEL,IXTBEN,IXTBCL,IXTBTK,
     &   IXTVTX,IXTTKS,IXKRES,
     &   IXUSR1,IXUSR2,IXUSR3,IXUSR4,IXUSR5,
     &   IXSPR1,IXSPR2,IXSPR3,IXSPR4,IXSPR5,
     &   IXCALB,
     &   IXTJCE,IXTJCT,IXTJT0,IXTJCZ,IXTJZ0,IXTJZL,IXTJST,IXTJCP,
     &   IXTJSL,IXTJSR,IXTJSZ,
     &   IXTJWR,IXTJRF,IXCJTF,IXCJNF,IXCJMX,
     &   IXCLGE,IXCBEF,IXCBEL,IXCBPF,IXCBPL,IXCBTF,IXCBXF,IXCBXL,
     &   IXCBCL,IXCBCF,IXCBRF,IXCBPC,
     &   IXCCRN,IXCCBF,IXCCPR,IXCCKL,
     &   IXWORK,IXEVNT,IXCONS,IXSAVE,
     &   IXSTOR
      INTEGER        LFRST,
     &   LEVHD,LHRAW,LHTJD,LHTBC,LHTRK,LHFIT,LHUSR,
     &   LRTRG,LRSFT,LRPWC,LRSCL,LRJDC,LRJDF,LRBCF,LRBCL,
     &   LRBCR,LRLAT,LRLPR,LRMON,LRENO,LRMCB,LRVTX,LRSVX,
     &   LDIST,LSWIT,LGEOM,LVERT,LKINE,LPHYS,LMCIN,LRTBF,LRTBL,
     &   LTJDC,LTPWC,LTCHT,LTCTK,LTCTR,LTCHX,LTCVX,LTVXT,
     &   LTBEF,LTBEL,LTBEN,LTBCL,LTBTK,
     &   LTVTX,LTTKS,LKRES,
     &   LUSR1,LUSR2,LUSR3,LUSR4,LUSR5,
     &   LSPR1,LSPR2,LSPR3,LSPR4,LSPR5,
     &   LCALB,
     &   LTJCE,LTJCT,LTJT0,LTJCZ,LTJZ0,LTJZL,LTJST,LTJCP,
     &   LTJSL,LTJSR,LTJSZ,
     &   LTJWR,LTJRF,LCJTF,LCJNF,LCJMX,
     &   LCLGE,LCBEF,LCBEL,LCBPF,LCBPL,LCBTF,LCBXF,LCBXL,
     &   LCBCL,LCBCF,LCBRF,LCBPC,LCBBS,LCBGE,LCBGN,LCBGM,LCBGO,
     &   LCCRN,LCCBF,LCCPR,LCCKL,
     &   LLAST
      INTEGER        IXCOMP,IXFRST,
     &   IXEVHD,IXHRAW,IXHTJD,IXHTBC,IXHTRK,IXHFIT,IXHUSR,
     &   IXRTRG,IXRSFT,IXRPWC,IXRSCL,IXRJDC,IXRJDF,IXRBCF,IXRBCL,
     &   IXRBCR,IXRLAT,IXRLPR,IXRMON,IXRENO,IXRMCB,IXRVTX,IXRSVX,
     &   IXDIST,IXSWIT,IXGEOM,IXVERT,IXKINE,IXPHYS,
     &   IXMCIN,IXRTBF,IXRTBL,
     &   IXTJDC,IXTPWC,IXTCHT,IXTCTK,IXTCTR,IXTCHX,IXTCVX,IXTVXT,
     &   IXTBEF,IXTBEL,IXTBEN,IXTBCL,IXTBTK,
     &   IXTVTX,IXTTKS,IXKRES,
     &   IXUSR1,IXUSR2,IXUSR3,IXUSR4,IXUSR5,
     &   IXSPR1,IXSPR2,IXSPR3,IXSPR4,IXSPR5,
     &   IXCALB,
     &   IXTJCE,IXTJCT,IXTJT0,IXTJCZ,IXTJZ0,IXTJZL,IXTJST,IXTJCP,
     &   IXTJWR,IXTJRF,IXCJTF,IXCJNF,IXCJMX,
     &   IXTJSL,IXTJSR,IXTJSZ,
     &   IXCLGE,IXCBEF,IXCBEL,IXCBPF,IXCBPL,IXCBTF,IXCBXF,IXCBXL,
     &   IXCBCL,IXCBCF,IXCBRF,IXCBPC,
     &   IXCCRN,IXCCBF,IXCCPR,IXCCKL,
     &   IXWORK,IXEVNT,IXCONS,IXSAVE,
     &   IXSTOR
*KEND.
*
      SAVE FIRST,LINEA
*
      DATA FIRST /.TRUE./
      DATA LINEA /64*0/
*
*     _________________________________
*
      IF(FIRST) THEN
*
         FIRST = .FALSE.
         DO 100 I = 1,63
            LINEA(I) = IFIX( FLOAT(I)*640. /
     &                     (64. - 0.7539*FLOAT(I)) + 0.5)
 100     CONTINUE
*
      ENDIF
*
 200  WRITE(LUN,2010)IEHDCB(4),IEHDCB(5),LRJDF
      IF(LRJDF .LE. 0) RETURN
      IF(IQ(LRJDF-1) .LE. 0) RETURN
*
      NDATA = JBYT(IQ(LRJDF+1), 1,16)
      ICODE = JBYT(IQ(LRJDF+1),17,16)
      WRITE(LUN,2020)IQ(LRJDF-1),NDATA,ICODE
*
      IRJDF = LRJDF+1
      IDATA = 1
*
 500  NI2   = JBYT(IQ(IRJDF+1),17,15)
      ISEC  = JBYT(IQ(IRJDF+1), 9, 8)
      ILYR  = JBYT(IQ(IRJDF+1), 1, 8)
      ITOF  = JBYT(IQ(IRJDF+2), 1,16)
      IPDL  = JBYT(IQ(IRJDF+3),17,16)
      IPDR  = JBYT(IQ(IRJDF+3), 1,16)
*
      WRITE(LUN,2030)ISEC,ILYR,NI2,ITOF,IPDL,IPDR
*
      NWORD = (NI2 + 1)/2
      IDATA = IDATA + NWORD + 3
      IF(IDATA .GT. NDATA) GOTO 1700
      I2CNT = 0
      IRJDF = IRJDF + 3
*
      DO 1000 I = 1,NWORD
*
         LGCRPT = .FALSE.
*
         I1L = JBYT(IQ(IRJDF+I),25, 6)
         I1R = JBYT(IQ(IRJDF+I),17, 6)
         IF((JBYT(IQ(IRJDF+I),31,2).NE.0) .OR.
     &      (JBYT(IQ(IRJDF+I),23,2).NE.0)) LGCRPT = .TRUE.
         WRITE(LUN,2040)I1L,I1R,LINEA(I1L),LINEA(I1R)
         IF(LGCRPT) WRITE(LUN,2043)
         I2CNT = I2CNT + 1
         IF(I2CNT .GE. NI2) GOTO 1000
*
         LGCRPT = .FALSE.
         I2L = JBYT(IQ(IRJDF+I), 9, 8)
         I2R = JBYT(IQ(IRJDF+I), 1, 8)
         IF((JBYT(IQ(IRJDF+I),15,2).NE.0) .OR.
     &      (JBYT(IQ(IRJDF+I), 7,2).NE.0)) LGCRPT = .TRUE.
         WRITE(LUN,2040)I2L,I2R,LINEA(I2L),LINEA(I2R)
         IF(LGCRPT) WRITE(LUN,2043)
         I2CNT = I2CNT + 1
*
 1000 CONTINUE
      IRJDF = IRJDF + NWORD
      IF(IDATA .LT. NDATA) GOTO 500
      LRJDF = LQ(LRJDF)
      IF(LRJDF .GT. 0) THEN
         WRITE(LUN,2050)
         GOTO 200
      ENDIF
      LRJDF = LQ(LHRAW-4)
      RETURN
 2050 FORMAT(' SECOND RJDF BANK FOUND.')
*
 1700 WRITE(LUN,1750)
 1750 FORMAT(' WARNING -- Data count doesnot match, exiting. ')
*
      RETURN
 2010 FORMAT(' Entry point to RJRJDF for run ',I5,' Event ',I5,
     &       ' LRJDF=',I16)
 2020 FORMAT(' Bank size ',I5,' Amount of data ',I5,' Code ',Z8)
 2030 FORMAT(' Sector  ',I4,' Layer ',I4,' No. of I*2 words ',I4,/,
     &       ' t_off ',I6,' ped_l ',I4,' ped_r ',I4,/,
     &       '    Non - linear      Linear ',/,
     &       '   Left     Right   Left    Right')
 2040 FORMAT(2X,I6,4X,I6,4X,I6,4X,I6)
 2043 FORMAT(' These data have been corrupted ')
      END
*CMZU:  1.99/11 06/07/95  23.46.40  by  Curtis A. Meyer
*CMZ :  1.45/00 15/01/91  13.50.21  by  Curtis A. Meyer
*CMZ :  1.42/00 11/07/90  08.27.17  by  Curtis A. Meyer
*-- Author :
      SUBROUTINE RJTJDC(LUN)
*
*        Author:        Curtis A Meyer
*
*        Creation date: March, 1988.
*
*        References:
*
*        Description:   This routine prints the data in the RJDC data
*                       bank which has been copied into the TJDC data bank
*                       by the TJDCGT routine. The format is essentially
*                       the same as the RJRJDC routine, except the data
*                       is now ordered by sector, layer and drift time.
*
*
*     ********************************************************************
*
*KEEP,IMPNONE,IF=-F77.
      IMPLICIT NONE
*KEND.
*
*        Passed variables:
*        LUN Logical unit for I/O.
*
      INTEGER       LUN
*
*        Internal variables:
*        ITJDC Pointer to the TJDC bank.
*        NHIT  the number of hits in the sector.
*        ISECT the sector number.
*        LAYER the layer number.
*        I,J   loop indicies.
*        VALUE contains drift time, ampl. left and right.
*
      INTEGER     ITJDC,NHIT,ISECT,LAYER,I,J
      REAL        VALUE(4)
*
*KEEP,TRKPRM.
      INTEGER    LENTJ,LENHT,LENTK,LENTR,LENHP,LENVX,LENVP
      INTEGER    LENJCP,LENPW,LENCL,LENVH
      INTEGER    LENSV,LENCLS,LENBP
      PARAMETER (LENTJ=16,LENHT=23,LENTK=30,LENTR=33,LENHP=6)
      PARAMETER (LENVX=14,LENVP=13,LENJCP=20)
      PARAMETER (LENPW=10,LENCL=12,LENVH=7)
      PARAMETER (LENSV=2, LENCLS=16,LENBP=2)
*KEEP,CBLINK.
      INTEGER ZBLENG
      PARAMETER (ZBLENG = 600000)
      INTEGER XELENG, XCLENG, XLQLNG, XIQLNG
      PARAMETER (XELENG = 100000)
      PARAMETER (XCLENG = ZBLENG-XELENG)
      PARAMETER (XLQLNG = ZBLENG + 100)
      PARAMETER (XIQLNG = ZBLENG +  92)
*      COMMON /CBBANK/ FENCCB(16),LSTRUC(10),LREFER(90),XEVTCB(40 000),
*     &                XCONCB(150 000)
*      INTEGER FENCCB,LSTRUC,LREFER,  LQ(190 100), IQ(190 092)
*      REAL    XEVTCB,XCONCB,         Q(190 092)
      COMMON /CBBANK/ FENCCB(16),LSTRUC(10),LREFER(90),XEVTCB(XELENG),
     &                XCONCB(XCLENG)
      INTEGER FENCCB,LSTRUC,LREFER,  LQ(XLQLNG), IQ(XIQLNG)
      REAL    XEVTCB,XCONCB,         Q(XIQLNG)
      EQUIVALENCE (LSTRUC(1),LQ(1))
      EQUIVALENCE (LQ(9),IQ(1))
      EQUIVALENCE (LQ(9),Q(1))
*
*  header words
*
      INTEGER    MAXHD
      PARAMETER (MAXHD=30)
      COMMON/CBHEAD/NEHDCB,IEHDCB(MAXHD),NRHDCB,IRHDCB(MAXHD)
      INTEGER NEHDCB,IEHDCB,NRHDCB,IRHDCB
*
      COMMON /CBLINK/ LFRST,
     &   LEVHD,LHRAW,LHTJD,LHTBC,LHTRK,LHFIT,LHUSR,
     &   LRTRG,LRSFT,LRPWC,LRSCL,LRJDC,LRJDF,LRBCF,LRBCL,
     &   LRBCR,LRLAT,LRLPR,LRMON,LRENO,LRMCB,LRVTX,LRSVX,
     &   LDIST,LSWIT,LGEOM,LVERT,LKINE,LPHYS,LMCIN,LRTBF,LRTBL,
     &   LTJDC,LTPWC,LTCHT,LTCTK,LTCTR,LTCHX,LTCVX,LTVXT,
     &   LTBEF,LTBEL,LTBEN,LTBCL,LTBTK,
     &   LTVTX,LTTKS,LKRES,
     &   LUSR1,LUSR2,LUSR3,LUSR4,LUSR5,
     &   LSPR1,LSPR2,LSPR3,LSPR4,LSPR5,
     &   LCALB,
     &   LTJCE,LTJCT,LTJT0,LTJCZ,LTJZ0,LTJZL,LTJST,LTJCP,
     &   LTJSL,LTJSR,LTJSZ,
     &   LTJWR,LTJRF,LCJTF,LCJNF,LCJMX,
     &   LCLGE,LCBEF,LCBEL,LCBPF,LCBPL,LCBTF,LCBXF,LCBXL,
     &   LCBCL,LCBCF,LCBRF,LCBPC,LCBBS,LCBGE,LCBGN,LCBGM,LCBGO,
     &   LCCRN,LCCBF,LCCPR,LCCKL,
     &   LLAST

      COMMON /CBXDIV/IXCOMP,IXFRST,
     &   IXEVHD,IXHRAW,IXHTJD,IXHTBC,IXHTRK,IXHFIT,IXHUSR,
     &   IXRTRG,IXRSFT,IXRPWC,IXRSCL,IXRJDC,IXRJDF,IXRBCF,IXRBCL,
     &   IXRBCR,IXRLAT,IXRLPR,IXRMON,IXRENO,IXRMCB,IXRVTX,IXRSVX,
     &   IXDIST,IXSWIT,IXGEOM,IXVERT,IXKINE,IXPHYS,
     &   IXMCIN,IXRTBF,IXRTBL,
     &   IXTJDC,IXTPWC,IXTCHT,IXTCTK,IXTCTR,IXTCHX,IXTCVX,IXTVXT,
     &   IXTBEF,IXTBEL,IXTBEN,IXTBCL,IXTBTK,
     &   IXTVTX,IXTTKS,IXKRES,
     &   IXUSR1,IXUSR2,IXUSR3,IXUSR4,IXUSR5,
     &   IXSPR1,IXSPR2,IXSPR3,IXSPR4,IXSPR5,
     &   IXCALB,
     &   IXTJCE,IXTJCT,IXTJT0,IXTJCZ,IXTJZ0,IXTJZL,IXTJST,IXTJCP,
     &   IXTJSL,IXTJSR,IXTJSZ,
     &   IXTJWR,IXTJRF,IXCJTF,IXCJNF,IXCJMX,
     &   IXCLGE,IXCBEF,IXCBEL,IXCBPF,IXCBPL,IXCBTF,IXCBXF,IXCBXL,
     &   IXCBCL,IXCBCF,IXCBRF,IXCBPC,
     &   IXCCRN,IXCCBF,IXCCPR,IXCCKL,
     &   IXWORK,IXEVNT,IXCONS,IXSAVE,
     &   IXSTOR
      INTEGER        LFRST,
     &   LEVHD,LHRAW,LHTJD,LHTBC,LHTRK,LHFIT,LHUSR,
     &   LRTRG,LRSFT,LRPWC,LRSCL,LRJDC,LRJDF,LRBCF,LRBCL,
     &   LRBCR,LRLAT,LRLPR,LRMON,LRENO,LRMCB,LRVTX,LRSVX,
     &   LDIST,LSWIT,LGEOM,LVERT,LKINE,LPHYS,LMCIN,LRTBF,LRTBL,
     &   LTJDC,LTPWC,LTCHT,LTCTK,LTCTR,LTCHX,LTCVX,LTVXT,
     &   LTBEF,LTBEL,LTBEN,LTBCL,LTBTK,
     &   LTVTX,LTTKS,LKRES,
     &   LUSR1,LUSR2,LUSR3,LUSR4,LUSR5,
     &   LSPR1,LSPR2,LSPR3,LSPR4,LSPR5,
     &   LCALB,
     &   LTJCE,LTJCT,LTJT0,LTJCZ,LTJZ0,LTJZL,LTJST,LTJCP,
     &   LTJSL,LTJSR,LTJSZ,
     &   LTJWR,LTJRF,LCJTF,LCJNF,LCJMX,
     &   LCLGE,LCBEF,LCBEL,LCBPF,LCBPL,LCBTF,LCBXF,LCBXL,
     &   LCBCL,LCBCF,LCBRF,LCBPC,LCBBS,LCBGE,LCBGN,LCBGM,LCBGO,
     &   LCCRN,LCCBF,LCCPR,LCCKL,
     &   LLAST
      INTEGER        IXCOMP,IXFRST,
     &   IXEVHD,IXHRAW,IXHTJD,IXHTBC,IXHTRK,IXHFIT,IXHUSR,
     &   IXRTRG,IXRSFT,IXRPWC,IXRSCL,IXRJDC,IXRJDF,IXRBCF,IXRBCL,
     &   IXRBCR,IXRLAT,IXRLPR,IXRMON,IXRENO,IXRMCB,IXRVTX,IXRSVX,
     &   IXDIST,IXSWIT,IXGEOM,IXVERT,IXKINE,IXPHYS,
     &   IXMCIN,IXRTBF,IXRTBL,
     &   IXTJDC,IXTPWC,IXTCHT,IXTCTK,IXTCTR,IXTCHX,IXTCVX,IXTVXT,
     &   IXTBEF,IXTBEL,IXTBEN,IXTBCL,IXTBTK,
     &   IXTVTX,IXTTKS,IXKRES,
     &   IXUSR1,IXUSR2,IXUSR3,IXUSR4,IXUSR5,
     &   IXSPR1,IXSPR2,IXSPR3,IXSPR4,IXSPR5,
     &   IXCALB,
     &   IXTJCE,IXTJCT,IXTJT0,IXTJCZ,IXTJZ0,IXTJZL,IXTJST,IXTJCP,
     &   IXTJWR,IXTJRF,IXCJTF,IXCJNF,IXCJMX,
     &   IXTJSL,IXTJSR,IXTJSZ,
     &   IXCLGE,IXCBEF,IXCBEL,IXCBPF,IXCBPL,IXCBTF,IXCBXF,IXCBXL,
     &   IXCBCL,IXCBCF,IXCBRF,IXCBPC,
     &   IXCCRN,IXCCBF,IXCCPR,IXCCKL,
     &   IXWORK,IXEVNT,IXCONS,IXSAVE,
     &   IXSTOR
*KEND.
*
*     ___________________________________________
*
      WRITE(LUN,100)IEHDCB(4),IEHDCB(5),LTJDC
 100  FORMAT(' TJDC bank contents: Run ',I7,' Event ',I9,
     &       ' LTJDC ',I9)
*
      IF(LTJDC .LE. 0) RETURN
      IF(IQ(LTJDC-1) .LE. 0) RETURN
*
*        Loop over the 30 sectors in the JDC, and identify which ones
*        have data.
*
      DO 1000 ISECT = 1,30
         NHIT = IQ(LTJDC+ISECT)
         IF(NHIT .GT. 0) THEN
            ITJDC = LQ(LTJDC-ISECT)
*
*              Loop over all the hits in the layer, and print them out.
*
            DO 500 I = 1,NHIT
               LAYER    =IQ(ITJDC+1)
               VALUE(1) = Q(ITJDC+5)
               VALUE(2) = Q(ITJDC+6)
               VALUE(3) = Q(ITJDC+7)
               VALUE(4) = Q(ITJDC+16)
               WRITE(LUN,1100)ISECT,LAYER,VALUE
               ITJDC = ITJDC + LENTJ
 500        CONTINUE
         ENDIF
 1000 CONTINUE
      RETURN
 1100 FORMAT(' sector:',I3,' layer:',I3,' time:',F7.3,
     &       ' ampl:',F9.3,2X,F9.3,' tgl ',F9.4)
      END
